("\"encryption\" features from the preference panel" "zna£ajke \"²ifriranja\" na preferencijskoj plo£i")
("a modifier" "modifikator A")
("a.C.M. computing class" "a.C.M. ra£unalni razred")
("a.M.S. subject class" "a.M.S. predmetni razred")
("a series" "serija A")
("abbreviated authors" "skra¢ena imena autora")
("abreviated authors" "skra¢ena imena autora")
("abbreviation" "kratica")
("about" "o programu")
("about menu" "izbornik o programu")
("above" "iznad")
("abstract" "saºetak")
("acceleration" "ubrzanje")
("accent" "naglasak")
("accent above" "naglasak iznad")
("accent below" "naglasak ispod")
("accept" "prihvati")
("accept all scripts" "prihvati sve skripte")
("accept during this pass" "prihvati za vrijeme ovog prolaza")
("accept no scripts" "ne prihva¢aj skripte")
("accept script" "prihvati skriptu")
("acknowledge" "zahvaljivanje")
("acknowledgment" "zahvala")
("acknowledgments" "zahvale")
("acronym" "akronim")
("action" "radnja")
("activate" "aktiviraj")
("activate once" "aktiviraj jednom")
("activate hidden" "aktiviraj skriveno")
("activation" "aktivacija")
("active link types" "aktivne vrste poveznica")
("acute" "o²tro")
("add" "dodaj")
("add abstract information" "dodaj podatke o saºetku")
("add author information" "dodaj podatke o autoru")
("add branch after" "dodaj ogranak nakon")
("add branch before" "dodaj ogranak prije")
("add package" "dodaj paket")
("add other package" "dodaj drugi paket")
("add remote ssh connection" "dodaj daljinsku SSH vezu")
("add style package" "dodaj stilski paket")
("add switch after" "dodaj skretnicu iza")
("add switch before" "dodaj skretnicu prije")
("add title information" "dodaj podatke o naslovu")
("add to custom colors" "dodaj u prilagoene boje")
("addition" "dodatak")
("address" "adresa")
("address block" "odjeljak s adresom")
("adjust" "prilagodi")
("adjust limits" "prilagodi granice")
("advanced" "napredno")
("advanced font customization" "napredna prilagodba fonta")
("advanced layout features" "napredna svojstva prijeloma")
("affiliation" "pripadnost")
("after" "nakon")
("albanian" "albanski")
("algorithm" "algoritam")
("align cell to the bottom" "poravnavanje ¢elije na dnu")
("align cell to the decimal comma" "poravnavanje ¢elije na decimalnoj to£ki")
("align cell to the decimal dot" "poravnavanje ¢elije na decimalnom zarezu")
("align cell to the left" "lijevo poravnavanje ¢elije")
("align cell to the right" "desno poravnavanje ¢elije")
("align cell to the top" "poravnavanje ¢elije na vrhu")
("align table at axis" "poravnavanje tablice prema osi")
("align table at base of left column" "poravnavanje tablice prema osnovici lijevog stupca")
("align table at base of middle column" "poravnavanje tablice prema osnovici srednjeg stupca")
("align table at base of origin column" "poravnavanje tablice prema osnovici polaznog stupca")
("align table at base of right column" "poravnavanje tablice prema osnovici desnog stupca")
("align table at fraction bar height" "poravnavanje tablice prema razloma£koj crti")
("align table at the base of bottom row" "poravnavanje tablice prema osnovici donjeg retka")
("align table at the base of middle row" "poravnavanje tablice prema osnovici srednjeg retka ")
("align table at the base of origin row" "poravnavanje tablice prema osnovici polaznog retka")
("align table at the base of top row" "poravnavanje tablice prema osnovici gornjeg retka")
("align table at the bottom" "poravnavanje tablice prema dnu")
("align table at the center" "poravnavanje tablice prema sredini")
("align table at the horizontal center" "poravnavanje tablice prema vodoravnoj sredini")
("align table at the left" "lijevo poravnavanje tablice")
("align table at the top" "poravnavanje tablice prema vrhu")
("align table to the right" "lijevo poravnavanje tablice")
("align text to the left" "lijevo poravnavanje teksta")
("align text to the right" "desno poravnavanje teksta")
("aligned" "poravnato")
("alignment" "poravnanje")
("alignment of balloon" "poravnanje obla£i¢a")
("all" "sve")
("all cells" "sve ¢elije")
("all data attached to this identity will be lost" "svi podaci vezani uz ovaj identitet bit ¢e izgubljeni")
("all saved passphrases will be lost forever" "sve spremljene zaporke bit ¢e nepovratno izgubljene")
("allow" "dopusti")
("allow authentification through cryptographic key" "dopusti autentifikaciju pomo¢u kriptografskog klju£a")
("allow authentification through password" "dopusti autentifikaciju pomo¢u zaporke")
("allow for macro definitions in preamble" "dopusti definicije makroa u preambuli")
("allow multiple spaces" "dopusti vi²estruke razmake")
("allow spurious spaces" "dopusti laºne razmake")
("allowed extension" "dopu²teno pro²irenje")
("allowed page height extension" "dopu²teno pove¢anje visine stranice")
("allowed page height reduction" "dopu²teno smanjenje visine stranice")
("allowed positions" "dopu²teni poloºaji") 
("allowed positions of floating object" "dopu²teni poloºaji plutaju¢eg objekta")
("allowed reduction" "dopu²teno smanjenje")
("alpha release" "alfa izdanje")
("alpha transparency" "alfa prozirnost")
("also on paper" "takoer na papiru")
("alt key" "alt")
("alter" "mijenjaj")
("alternate" "zamjenski")
("alternate except here" "zamjenski, osim ovdje")
("alternate from here on" "zamjenski odavde nadalje")
("alternate only here" "zamjenski samo ovdje")
("alternate TeXmacs command" "zamjenska TeXmacs naredba")
("alternate until here" "zamjenski do ovdje")
("alternative colors" "zamjenske boje")
("alternative specification" "zamjenska specifikacija")
("always" "uvijek")
("american" "ameri£ki")
("amplified" "poja£ano")
("anchor" "sidro")
("ancient" "anti£ki")
("and" "i")
("and perform casual settings from the \"Encryption\" tab" "i izvr²ite usputne postavke s kartice \"²ifriranje\"")
("angle" "kut")
("angular" "uglato")
("animate" "animiraj")
("animate folding" "animiraj preklapanje")
("animate objects" "animiraj objekte")
("animate unfolding" "animiraj razvijanje")
("animated" "animirano")
("animation" "animacija")
("animation toolbar" "alatna traka za animacije")
("annotate" "napravi pribilje²ke")
("annote" "pribiljeºi")
("answer" "odgovor")
("answer field" "polje odgovora")
("answer to question" "odgovor na pitanje")
("answers only" "samo odgovori")
("any" "bilo koje")
("appear" "pojavljivanje")
("appendix" "dodatak")
("apply" "primijeni")
("apply macro" "primijeni makro")
("apply macro once" "primijeni makro jednom")
("approximate" "pribliºno odredi")
("april" "travanj")
("arab" "arapski")
("arc" "luk")
("arc cosine" "arkus kosinus")
("arc sine" "arkus sinus")
("arc tangent" "arkus tangens")
("arch series" "serija ARCH")
("archaic" "arhai£no")
("architecture" "arhitektura")
("are you sure you want to delete collected public keys" "jeste li sigurni da ºelite izbrisati prikupljene javne klju£eve")
("are you sure you want to delete selected public keys" "jeste li sigurni da ºelite izbrisati odabrane javne klju£eve")
("are you sure you want to delete selected secret keys" "jeste li sigurni da ºelite izbrisati odabrane tajne klju£eve")
("are you sure you want to destroy the wallet" "jeste li sigurni da ºelite uni²titi lisnicu")
("area" "povr²ina")
("art frame" "umjetni£ki okvir")
("art Pen" "umjetni£ka pisaljka")
("arithmetic" "aritmetika")
("armenian" "armenski")
("around" "okruºeno")
("arrow" "strelica")
("arrows" "strelice")
("article" "£lanak")
("arxiv category" "arxiv kategorija")
("as on paper" "kao na papiru")
("as visual grid" "kao vizualna mreºa")
("aspect" "aspekt")
("assign" "dodijeli")
("at fraction bar height" "na visini razloma£ke crte")
("at the baseline" "na osnovici")
("at the bottom" "na dnu")
("at the left" "nalijevo")
("at the middle" "po sredini")
("at the right" "nadesno")
("at the top" "na vrhu")
("attach" "priloºi")
("attach buffer to which project" "kojem projektu priloºiti spremnik")
("attach master" "prika£i master")
("attach master file for project" "prika£i master datoteku za projekt")
("attached" "prika£eno")
("avoid spurious spaces" "izbjegavanje laºnih razmaka")
("august" "kolovoz")
("author" "autor")
("author affiliation" "pripadnost autora")
("author email" "e-po²ta autora")
("author homepage" "web-stranica autora")
("author misc" "razno o autoru")
("author name" "ime autora")
("author note" "bilje²ka o autoru")
("authorize" "autoriziraj")
("auto" "automatski")
("auto-correlation" "autokorelacija")
("auto-save file" "pohrani datoteku automatski")
("automatic" "automatski")
("automatic brackets" "automatske zagrade")
("automatic content generation" "automatsko generiranje sadrºaja")
("automatic program brackets" "automatske zagrade u programima")
("automatically close brackets" "automatsko zatvaranje zagrada")
("automatically generated content" "automatski generiran sadrºaj")
("automatically import bibliographies when opening files" "automatski uvezi popise literature prilikom otvaranja datoteke")
("automatically open this console on errors" "automatski otvori ovu konzolu u slu£aju gre²ke")
("automatically open this console on warnings" "automatski otvori ovu konzolu u slu£aju upozorenja")
("automatically remember all passphrases in the wallet" "automatski zapamti sve zaporke u lisnici")
("automatically save" "automatsko pohranjivanje")
("automatic quotes" "automatski navodnici")
("autosave" "automatsko pohranjivanje")
("axis" "os")
("axiom" "aksiom")
("b series" "serija B")
("back" "natrag")
("background" "pozadina")
("background color" "boja pozadine")
("background evaluations" "evaluacija u pozadini")
("background pattern" "pozadinski uzorak")
("background picture" "pozadinska slika")
("background picture selector" "izbornik pozadinske slike")
("backtrace errors" "povratno pra¢enje pogre²aka")
("backward replace" "zamjenjuj unatrag")
("backward search" "traºi unatrag")
("bad data format" "lo² format podataka")
("balloon" "obla£i¢")
("bar" "bar")
("base" "baza")
("base level" "osnovni nivo")
("baseline" "osnovica")
("basis" "baza")
("bashkirian" "bashkirijski")
("basic" "osnovno")
("basic colors" "osnovne boje")
("basic communication using pipes" "osnovna komunikacija preko cijevi")
("basic data types" "osnovne vrste podataka")
("basic types" "osnovne vrste")
("be useful" "budi koristan")
("beamer" "projektor")
("beamer formats" "formati za projektor")
("beamer theme" "tema projektora")
("become a TeXmacs developer" "postani razvijatelj TeXmacsa")
("before" "prije")
("begin" "po£etak")
("below" "ispod")
("bench" "prag")
("bend bottom" "savij dno")
("bend corner" "savij ugao")
("bend diagonal" "savij dijagonalno")
("bend in" "savij prema unutra")
("bend out" "savij prema van")
("beta release" "beta izdanje")
("bezier" "Bezier")
("bibliography" "literatura")
("bibliography file" "datoteka s popisom literature")
("bibliography style" "stil popisa literature")
("bibTeX command" "bibTeX naredba")
("bidirectional" "dvosmjerni")
("big" "veliko")
("big environment box" "velika kutija okruºenja")
("big figure" "velika slika")
("big focus" "veliki fokus")
("big operator" "veliki operator")
("big skip" "veliki preskok")
("big table" "velika tablica")
("binary operation" "binarna operacija")
("binary operator" "binarni operator")
("binary relation" "binarna relacija")
("bitmap resolution" "razlu£ivost slike")
("black" "crno")
("black floral I" "crno cvjetno 1")
("black floral II" "crno cvjetno 2")
("black floral1 frame" "crni cvjetni okvir 1")
("black floral2 frame" "crni cvjetni okvir 2")
("blackboard" "²kolska plo£a")
("blackboard bold" "dvostruko podebljano")
("blackboard embold" "dvostruko podebljaj")
("blackboard math" "dvostruka podebljana matemati£ka slova")
("blackletter" "goti£ki font")
("blank column" "prazan stupac")
("blank row" "prazan redak")
("block" "blok")
("block content" "blokiraj sadrºaj")
("block of code" "blok programskog koda")
("blue" "plavo")
("bluish" "plavi£asto")
("blur" "zamagli")
("blur radius" "radijus zamagljenja")
("body" "tijelo")
("body color" "boja tijela")
("bold" "podebljano")
("book" "knjiga")
("booklet" "bro²ura")
("border" "rub")
("boring" "dosadno")
("boring white" "dosadno bijelo")
("both" "oba")
("both versions" "obje ina£ice")
("bothlined" "dvolinijski")
("bottom" "dno")
("bottom baseline" "donja osnovica")
("bottom border" "donji rub")
("bottom cell border" "donji rub ¢elije")
("bottom cell padding" "donja ispuna ¢elije")
("bottom center" "na dnu po sredini")
("bottom left" "na dnu lijevo")
("bottom margin" "donja margina")
("bottom padding" "donja ispuna")
("bottom right" "na dnu desno")
("bottom table border" "donji rub tablice")
("bottom table padding" "donja ispuna tablice")
("bottom tools" "alati na dnu")
("box" "kutija")
("branch" "ogranak")
("break" "prijelom")
("breaking" "prelamanje")
("breve" "breve")
("british" "britanski")
("broken white" "razbijeno bijelo")
("brown" "smeei")
("browse" "prebiranje")
("browse back" "prebiranje unatrag")
("browse forward" "prebiranje unaprijed")
("browse modules documentation" "prebiranje dokumentacije za module")
("browse symbols documentation" "prebiranje dokumentacije za simbole")
("browse web" "prebiranje WEB-a")
("browser" "prebirnik")
("buffer" "spremnik")
("buffer in this window" "spremnik u ovom prozoru")
("buffer management" "upravljanje spremnicima")
("buffer must be on disk" "spremnik mora biti na disku")
("buffer must have a name" "spremnik mora imati naziv")
("build buffer" "izgradi spremnik")
("build buffer in" "izgradi spremnik u")
("build directory" "izgradi direktorij")
("build directory in" "izgradi direktorij u")
("build link pages" "izgradi stranice poveznica")
("build-all" "izgradi sve")
("bulgarian" "bugarski")
("bullet" "znak nabrajanja")
("bullets" "znakovi nabrajanja")
("bump" "ispup£enje")
("busy" "zauzeto")
("by" "sa")
("by typing" "tipkanjem")
("bytes free" "bajtova slobodno")
("bytes used" "bajtova zauzeto")
("c++ Source Code" "izvorni C++ kod")
("calc table" "prora£unska tablica")
("calculus" "diferencijalni i integralni ra£un")
("calculus of variations" "varijacijski ra£un")
("calligraphic" "kaligrafski")
("cancel" "otkaºi")
("cancelled" "otkazano")
("cannot download directory to file" "ne mogu preuzeti direktorij kao datoteku")
("cannot rename across different servers" "ne mogu preimenovati po razli£itim posluºiteljima")
("cannot upload directory to file" "ne mogu prenijeti direktorij kao datoteku")
("caps-lock key" "caps Lock tipka")
("caption" "natpis")
("caption left padding" "lijeva ispuna natpisa")
("caption right padding" "desna ispuna natpisa")
("captions above" "natpisi iznad")
("case" "case")
("case-insensitive search" "neosjetljivo pretraºivanje")
("cartoon" "karikatura")
("cartesian" "kartezijev")
("carved" "rezbareno")
("carved wood" "rezbareno drvo")
("carved wood frame" "okvir od rezbarenog drva")
("categories" "kategorije")
("category" "kategorija")
("cc" "kopija")
("cell" "¢elija")
("cell background color" "boja pozadine ¢elije")
("cell border" "rub ¢elije")
("cell color" "boja ¢elije")
("cell height" "visina ¢elije")
("cell inert" "inertna ¢elija")
("cell operation mode" "operativni reºim ¢elije")
("cell output" "izlaz ¢elije")
("cell properties" "svojstva ¢elije")
("cell span" "protezanje ¢elije")
("cell width" "²irina ¢elije")
("cells" "¢elije")
("center" "sredina")
("center text" "poravnavanje teksta po sredini")
("centered" "poravnato po sredini")
("centered block" "blok poravnat po sredini")
("centered programs" "programi poravnati po sredini")
("centered tabular" "tablica poravnata po sredini")
("chalk" "kreda")
("change border of cell" "promijeni rub ¢elije")
("change cell operation mode" "promijeni operativni reºim ¢elije")
("change default unit" "promijeni zadanu jedinicu")
("change log" "promijeni zapisnik")
("change passphrase" "promijeni zaporku")
("change step-size" "promijeni veli£inu koraka")
("change tags" "promijeni okruºenja")
("change the border of the table" "promijeni rub tablice")
("change the style of mathematical formulas" "promijeni stil matemati£kih formula")
("change the TeXmacs preferences" "prilagodi TeXmacs")
("changes" "promjene")
("chapter" "poglavlje")
("character compression" "sabijanje znakova")
("character contraction" "kontrakcija znakova")
("character count" "broj znakova")
("character encoding" "kodiranje znakova")
("character expansion" "ekspanzija znakova")
("check" "kva£ica")
("check exported Pdf files for correctness" "provjeri ispravnost izvezenih PDF datoteka")
("check for updates" "provjeri dostupna aºuriranja")
("check text for spelling errors" "provjeri pravopis u tekstu")
("checkable field" "polje s kva£icom")
("chinese" "kineski")
("choice" "izbor")
("cipher algorithm for passphrase encryption" "algoritam za ²ifriranje zaporke")
("circle" "krug")
("citation" "citat")
("cite" "citiranje")
("cite detail" "detaljno citiranje")
("cite related work" "citiranje povezanih radova")
("cite TeXmacs" "citiraj TeXmacs")
("cJK" "CJK")
("cJK spacing" "CJK razmicanje")
("class" "razred")
("classes" "razredi")
("classic" "klasi£no")
("classification" "klasifikacija")
("clean slate" "£isti ²kriljevac")
("clear" "obri²i")
("clear all fields" "obri²i sva polja")
("clear font cache" "obri²i predmemoriju fonta")
("clear local information" "obri²i lokalne informacije")
("clear menu" "isprazni izbornik")
("click Ok button twice to discard this warning" "dva puta kliknite gumb \"U redu\" da biste odbacili ovo upozorenje")
("clear selection" "obri²i selekciju")
("clear undo history" "izbri²i povijest poni²tavanja")
("client" "klijent")
("clip" "podreºi")
("clipboard image format" "format slike za meuspremnik")
("clipped" "podrezano")
("clipped and magnified" "podrezano i pove¢ano")
("clipped and resized" "podrezano i promijenjene veli£ine")
("clone" "udvoji")
("clone window" "udvoji prozor")
("close" "zatvori")
("close TeXmacs" "zatvori TeXmacs")
("close buffer" "zatvori spremnik")
("close document" "zatvori dokument")
("close replace tool" "zatvori alat za zamjenjivanje")
("close search tool" "zatvori alat za pretraºivanje")
("close spell tool" "zatvori alat za provjeru pravopisa")
("close session" "zatvori sesiju")
("close translations to rebuild" "zatvori datoteku prijevoda za ponovno izgraivanje")
("close window" "zatvori prozor")
("closed bezier" "zatvoreni Bezier")
("closed curve" "zatvorena krivulja")
("closed smooth" "zatvoreno glatko")
("closed spline" "zatvoreni splajn")
("closing" "zatvaranje")
("closing style" "stil zatvaranja")
("cluster by affiliation" "grupiraj po pripadnosti")
("code" "programski kod")
("covariance" "kovarijanca")
("collect garbage" "pokupi otpad")
("collected keys" "sakupljeni klju£evi")
("color" "boja")
("color according to nesting level" "odgovaraju¢a boja za nivo gnijeºenja")
("color of the axes" "boja osi")
("color of the subunits" "boja podjedinica")
("color of the units" "boja jedinica")
("colors" "boje")
("column" "stupac")
("column contains glued items" "stupac sadrºi slijepljene elemente")
("column separation" "odvajanje stupaca")
("column to the left" "stupac slijeva")
("column to the right" "stupac zdesna")
("columns" "stupci")
("columns separation" "odvajanje stupaca")
("comic" "stripovski")
("command" "naredba")
("commit file" "predaj datoteku")
("common" "uobi£ajeno")
("common formats" "uobi£ajeni formati")
("commutative diagram" "komutativni dijagram")
("compact" "kompaktno")
("compact lists" "kompaktni popisi")
("compactification" "kompaktifikacija")
("compactify" "kompaktificiraj")
("compare" "usporedi")
("compare with" "usporedi sa")
("compare with newer version" "usporedi s novijom ina£icom")
("compare with older version" "usporedi sa starijom ina£icom")
("compatibility with other formats" "kompatibilnost s drugim formatima")
("compile article" "kompiliraj £lanak")
("compile book" "kompiliraj knjigu")
("compile buffer" "kompiliraj spremnik")
("compile project" "kompiliraj projekt")
("complete bibliographic reference" "cjelovita bibliografska referenca")
("completion" "zavr²etak")
("complex" "kompleksni")
("complex actions" "sloºene radnje")
("complex numbers" "kompleksni brojevi")
("compose" "slaganje")
("compound" "sloºenica")
("compress" "komprimiraj")
("compress into toolbar" "sabij u alatnu traku")
("compressed" "komprimirano")
("conceal" "prikrivanje")
("concrete" "concrete")
("condensed" "stisnuto")
("condition" "uvjet")
("conference" "konferencija")
("configuration" "konfiguracija")
("configure look and feel" "konfiguriranje izgleda i dojma")
("confirm database entry" "potvrdi upis u bazi podataka")
("confirm entry" "potvrdi upis")
("confirm selected database entries" "potvrdi odabrane upise u bazi podataka")
("confirm selected entries" "potvrdi odabrane upise")
("conjecture" "pretpostavka")
("conservative conversion options" "mogu¢nosti konzervativne pretvorbe")
("consoles" "konzole")
("constants" "konstante")
("constellation" "konstelacija")
("contact" "kontakt")
("content" "sadrºaj")
("content tag" "okruºenja sadrºaja")
("context aids" "kontekstna pomagala")
("context dependent icons" "ikone ovisne o kontekstu")
("contextual hints" "kontekstualni savjeti")
("continuation of" "nastavak")
("continue" "nastavi")
("continued fraction" "veriºni razlomak")
("contour" "kontura")
("contract logarithms" "sabijanje logaritama")
("contribute" "pridonesi")
("control flow" "kontrola tijeka")
("control the evaluation of expressions" "kontroliraj evaluaciju izraza")
("convention" "konvencija")
("convolution" "konvolucija")
("convert" "konverzija")
("converters" "konverteri")
("converters to other data formats" "konverteri u druge formate podataka")
("convertible" "konvertibilno")
("cosine" "kosinus")
("copy" "kopiraj")
("copy text" "kopiraj tekst")
("copy to" "kopiraj u")
("copying" "kopiranje")
("copyright" "za²tita autorskog prava")
("cork charset with TeX catcode definition in preamble" "CORK kodiranje s TeX catcode definicijom u preambuli")
("corollary" "korolar")
("correct" "ispravno")
("correct all" "ispravi sve")
("correct formula" "ispravi formulu")
("correct manually" "ispravi ru£no")
("correct mathematical formulas" "ispravi matemati£ke formule")
("correct text" "ispravi tekst")
("correction" "ispravak")
("correlation" "korelacija")
("could not load" "nemogu¢e je u£itati")
("count characters" "prebroji znakove")
("count lines" "prebroji retke")
("count words" "prebroji rije£i")
("course" "te£aj")
("create a new document" "stvori novi dokument")
("create context macro" "stvori kontekstualni makro")
("create link" "stvori poveznicu")
("create preamble" "stvori preambulu")
("create remote account" "stvori udaljeni korisni£ki ra£un")
("create shortcut" "stvori pre£icu")
("create subprogram" "stvori podprogram")
("create subsession" "stvori podsesiju")
("create table macro" "stvori tabli£ni makro")
("create web site" "stvori web-stranicu")
("created new document" "kreiran je novi dokument")
("creating new account" "stvaranje novog ra£una")
("creating technical pictures" "kreiranje tehni£kih crteºa")
("croatian" "hrvatski")
("crop" "podreºi")
("crop marks" "oznake podrezivanja")
("cross" "kriº")
("cross-correlation" "unakrsna korelacija")
("crossed boxes" "prekriene kutije")
("crossed circles" "prekrieni krugovi")
("cumulative frequencies" "kumulativne frekvencije")
("current graphical mode" "trenutni reºim grafike")
("current user version" "trenutna korisni£ka ina£ica")
("current version" "trenutna ina£ica")
("cursor" "pokaziva£")
("cursors" "pokaziva£i")
("curve" "krivulja")
("curve fitting" "uklapanje krivulja")
("curve intersections" "sjeci²ta krivulja")
("curve points" "to£ke krivulje")
("custom colors" "prilagoene boje")
("custom tab" "prilagoeni tabulator")
("customizations" "prilagodbe")
("customize macro" "prilagodi makro")
("customizing and extending the user interface" "prilagoavanje i pro²irivanje korisni£kog su£elja")
("customizing TeXmacs" "prilagoavanje TeXmacsa")
("customizing the TeXmacs styles" "prilagoavanje TeXmacs stilova")
("cut" "izreºi")
("cut text" "izreºi tekst")
("cut to" "izreºi u")
("cyan" "cijan")
("cypriot" "cypriot")
("cyrillic" "¢irilica")
("cyrillic input method" "metoda unosa ¢irilice")
("cyrillic italic right" "¢irilica kurziv u desno")
("czech" "£e²ki")
("dancers" "plesa£i")
("danish" "danski")
("dark" "tamno")
("dark grey" "tamosiva")
("dark vador" "tamni vador")
("dash" "crtica")
("dashes" "crtice")
("data" "podaci")
("data conversion" "pretvorba podataka")
("data format" "format podataka")
("database entry" "upis u bazu podataka")
("database tool" "alat za baze podataka")
("database toolbar" "alatna traka za baze podataka")
("date" "datum")
("deactivate" "deaktiviraj")
("deactivate once" "deaktiviraj samo jednom")
("deactivate table" "deaktiviraj tablicu")
("dead" "mrtav")
("debug" "otkloni programske pogre²ke")
("debugging console" "konzola za otklanjanje programskih pogre²aka")
("debugging tool" "alat za otklanjanje programskih pogre²aka")
("december" "prosinac")
("decimal comma" "decimalni zarez")
("decimal dot" "decimalna to£ka")
("decomposed" "rastavljeno")
("decorate atoms" "ukrasi atome")
("decorated" "ukra²eno")
("decorated wood" "ukra²eno drvo")
("decorated wood frame" "okvir od ukra²enog drva")
("decorative" "ukrasno")
("decrease size" "umanji")
("decrypt" "de²ifriranje")
("default" "zadano")
("default padding" "zadana ispuna")
("default size" "zadana veli£ina")
("definition" "definicija")
("definition of" "definicija pojma")
("degrade" "degradiraj")
("degraded" "degradirano")
("delete" "ukloni")
("delete column" "ukloni stupac")
("delete documentation cache" "izbri²i predmemoriju dokumentacije")
("delete entries" "ukloni upise")
("delete link" "ukloni poveznicu")
("delete row" "ukloni redak")
("deleted" "uklonjeno")
("denominator" "nazivnik")
("describe" "opi²i")
("describe tag" "opi²i okruºenje")
("description" "opis")
("description aligned" "poravnato opisivanje")
("description compact" "kompaktno opisivanje")
("description dash" "opisivanje sa crticama")
("description long" "dulje opisivanje")
("description paragraphs" "opisivanje u odlomcima")
("descriptive" "opisno")
("descriptive table" "opisna tablica")
("destination" "odredi²te")
("destroy" "uni²ti")
("detach" "odvoji")
("detach master" "odvoji master")
("detailed" "detaljno")
("detailed menus" "detaljni izbornici")
("details in menus" "detalji u izbornicima")
("determinant" "determinanta")
("determine margins from text width" "odredi margine s obzirom na ²irinu teksta") 
("devangari" "devangari")
("developer" "razvijatelj")
("developer tool" "razvojni alat")
("developers guide" "vodi£ za razvijatelje")
("device" "ureaj")
("diamond" "romb")
("differentiate" "deriviraj")
("digital" "digitalno")
("dilate" "pro²iri")
("directory" "direktorij")
("direction of progression" "smjer progresije")
("direction of translation" "smjer translacije")
("disable" "onemogu¢i")
("disable coloring on paper" "onemogu¢i bojanje na papiru")
("disable encryption" "onemogu¢i ²ifriranje")
("disable first indentation" "onemogu¢i prvu uvlaku")
("disable first indentation after" "onemogu¢i prvu uvlaku nakon")
("disable first indentation before" "onemogu¢i prvu uvlaku prije")
("disable indentation" "onemogu¢i uvla£enje")
("disable indentation after" "onemogu¢i uvla£enje nakon")
("disable indentation before" "onemogu¢i uvla£enje prije")
("disabled" "onemogu¢eno")
("disallow" "ne dopusti")
("disappear" "nestani")
("disk" "disk")
("displayed formula" "prikazana formula")
("display style" "stil prikaza")
("dissociate joined cells" "razgrupiraj zdruºene ¢elije")
("distill encapsulated Pdf files" "destiliraj inkapsulirane PDF datoteke")
("distort" "iskrivi")
("distorted" "iskrivljeno")
("distribute unused space" "razdijeli neupotrijebljen prostor")
("division" "divizija")
("do not remap" "ne mapiraj ponovno")
("do not break up large formulas" "ne prelamaj duga£ke formule")
("doc title" "naslov dokumenta")
("document" "dokument")
("document font selector" "izbornik fonta dokumenta")
("document format" "oblikovanje dokumenta")
("document language" "jezik dokumenta")
("document metadata" "metapodaci dokumenta")
("document page format" "oblikovanje stranice dokumenta")
("document paragraph format" "oblikovanje odlomka dokumenta")
("document source tree preferences" "postavke izvornog stabla dokumenta")
("document style" "stil dokumenta")
("document styles" "stilovi dokumenta")
("document updates run" "aºuriranja dokumenta su pokrenuta")
("documentation" "dokumentacija")
("documents are trees" "dokumenti su stabla")
("documents in separate windows" "dokumenti u razli£itim prozorima")
("dot" "to£kica")
("dots" "to£kice")
("double stroke" "precrtaj dvaput")
("double the zoom factor for TeXmacs documents" "udvostru£i faktor pove¢anja za TeXmacs dokumente")
("down" "dolje")
("download" "preuzmi")
("downwards" "prema dolje")
("dpi" "dpi")
("dragging" "vu£enje")
("draw" "crtanje")
("draw graphics" "crtaj grafiku")
("draw image" "crtaj sliku")
("draw over" "crtaj preko")
("draw over selection" "crtaj preko selekcije")
("draw under" "crtaj ispod")
("drop" "ispusti")
("due to" "uslijed")
("duration" "trajanje")
("duplicate" "duplikat")
("dutch" "nizozemski")
("dynamic" "dinami£ki")
("dynamic libraries" "dinami£ke knjiºnice")
("echelon" "e²alon")
("edit" "uredi")
("edit animation" "uredi animaciju")
("edit groups of objects" "uredi grupe objekata")
("edit keyboard shortcuts" "uredi pre£ice tipkovnice")
("edit macro" "uredi makro")
("edit macros" "uredi makroe")
("edit package" "uredi paket")
("edit preamble" "uredi preambulu")
("edit source" "uredi izvor")
("edit source tree" "uredi izvorno stablo")
("edit style" "uredi stil")
("edit translations file" "uredi datoteku prijevoda")
("editing tools" "alati za ureivanje")
("education" "obrazovanje")
("effect pen" "pisaljka za efekt")
("eigenvalues" "svojstvene vrijednosti")
("eigenvalues and vectors" "svojstvene vrijednosti i vektori")
("eighth" "osmo")
("electricity" "elektricitet")
("elementary functions" "elementarne funkcije")
("email" "e-po²ta")
("embold" "podebljaj")
("emboss" "reljefno")
("emphasize" "naglasi")
("emphasize text" "naglasi tekst")
("empty box" "prazna kutija")
("enable first indentation" "omogu¢i prvo uvla£enje")
("enable first indentation after" "omogu¢i prvo uvla£enje nakon")
("enable first indentation before" "omogu¢i prvo uvla£enje prije")
("enable indentation" "omogu¢i uvla£enje")
("enable indentation after" "omogu¢i uvla£enje nakon")
("enable indentation before" "omogu¢i uvla£enje prije")
("enable page breaking" "omogu¢i prijelom preko vi²e stranica")
("enabled" "omogu¢eno")
("encl" "prilozi")
("encoding" "kodiranje")
("encryption" "²ifriranje")
("encryption facilities are not currently available" "ureiaji za ²ifriranje trenutno nisu dostupni")
("encryption facilities have not been enabled for TeXmacs" "mogu¢nosti enkripcije nisu omogu¢ene za TeXmacs")
("end" "end")
("energy" "energija")
("enforce brackets to match" "forsiraj sparivanje zagrada")
("english" "engleski")
("engrave" "ugravirano")
("enter a title" "unesi naslov")
("enter data" "unesi podatke")
("enter graphics" "unesi grafiku")
("enter graphic mode" "aktiviraj grafi£ki na£in")
("enter new passphrase for encryption" "unesi novu zaporku za ²ifriranje")
("enter passphrase for decryption" "unesi zaporku za de²ifriranje")
("enter passphrase for identity" "unesi zaporku za identitet")
("enter title information" "unesi podatke o naslovu")
("entire table" "cijela tablica")
("entry" "upis")
("entry type" "vrsta upisa")
("entry up to date in database" "dosada²nji upis u bazi podataka")
("enumerate" "nabrajanje")
("enunciation" "proglas")
("environment" "okruºenje")
("environment variable" "varijabla okruºenja")
("environments" "okruºenja")
("epilogue" "epilog")
("eqref" "referenca na jednadºbu")
("equal" "jednako")
("equation" "jednadºba")
("equations" "jednadºbe")
("equivalent for" "ekvivalent za")
("erode" "erodiraj")
("eRROR" "pogre²ka")
("error" "pogre²ka")
("error messages" "poruke o pogre²kama")
("error output" "izlaz za pogre²ke")
("error status report" "izvje²¢e o stanju pogre²ke")
("error: bracket does not match" "pogreka: nosa se ne podudara")
("error: cyclic or missing chunks detected" "pogre²ka: detektirani su cikli£ki ili nedostaju¢i dijelovi")
("error: file not found" "pogre²ka: datoteka nije pronaena")
("error: ghostview does not seem to be installed on your system" "pogre²ka: £ini se da GhostView nije instaliran u va² sustav")
("error: one of the alternatives should be filled out" "pogre²ka: treba ispuniti jednu od alternativa")
("error: only one alternatives should be filled out" "pogre²ka: treba ispuniti samo jednu opciju")
("error: should fill out name for referencing" "pogre²ka: treba ispuniti naziv za referencu")
("error: should fill out required field" "pogre²ka: treba popuniti obavezno polje")
("esperanto" "esperanto")
("etruscan" "etrurski")
("europe" "europa")
("european numbering style" "europski stil numeriranja")
("evaluable field" "izra£unljivo polje")
("evaluate" "evaluiraj")
("evaluate above" "evaluiraj iznad")
("evaluate all" "evaluiraj sve")
("evaluate below" "evaluiraj ispod")
("evaluate fields" "evaluiraj polja")
("evaluate fields in order" "evaluiraj polja po redu")
("evaluate scheme expression" "evaluiraj SCHEME izraz")
("evaluation" "evaluacija")
("evaluation switch" "skretnica za evaluaciju")
("evaluation tag" "okruºenje za evaluaciju")
("even page" "parna stranica")
("even page footer" "podnoºje parne stranice")
("even page header" "zaglavlje parne stranice")
("even page margin" "margina parne stranice")
("even page left margin" "lijeva margina parne stranice")
("even page shift" "pomak parne stranice")
("even pages" "parne stranice")
("events" "dogaaji")
("exact" "egzaktno")
("exact horizontal" "egzaktno vodoravno")
("exact mode" "egzaktni na£in")
("exam" "ispit")
("example" "primjer")
("exclusive" "isklju£ivo")
("exclusive or" "isklju£ivo ili")
("executable" "izvr²no")
("execute" "izvr²i")
("execute a TeXmacs command" "izvr²i TeXmacs naredbu")
("execute system command" "izvr²i sistemsku naredbu")
("executive" "executive")
("exercise" "zadatak")
("exit graphics mode" "izlaz iz grafi£kog na£ina")
("exit left" "izlaz na lijevo")
("exit right" "izlaz na desno")
("exit tag on the left" "napusti okruºenje na lijevo")
("exit tag on the right" "napusti okruºenje na desno")
("expand" "pro²irivanje")
("expand beamer slides" "pro²iri slajdove za projektor")
("expand logarithms" "pro²irivanje logaritama")
("expand inclusions" "pro²irivanje uklju£enja")
("expand TeXmacs macros with no LaTeX equivalents" "nemoj pro²iriti TeXmacs makroe ekvivalentima u LaTeXu")
("expand trigonometric functions" "pro²irivanje trigonometrijskih izraza")
("expand unrecognized macros" "pro²irivanje neprepoznatih makroa")
("expand user-defined macros" "pro²irivanje korisni£kih makroa")
("expanded" "pro²ireno")
("experimental" "eksperimentalno")
("experimental features (to be used with care)" "eksperimentalna svojstva (koristiti uz oprez)")
("explain" "objasni")
("explanatory item" "obja²njenje")
("explained" "obja²njeno")
("explicit keystroke" "eksplicitna tipka")
("explicit margins" "eksplicitne margine")
("exponential" "eksponecijalno")
("exponential functions" "eksponecijalne funkcije")
("export" "izvoz")
("export as" "izvezi kao")
("export bibliography" "izvezi popis literature")
("export bibliographies as links" "izvezi popise literature kao poveznice")
("export entries in buffer" "izvezi upise u spremniku")
("export file" "izvezi datoteku")
("export formulas as images" "izvezi formule kao slike")
("export mathematical formulas as images" "izvezi matemati£ke formule kao slike")
("export mathematical formulas as MathJax" "izvezi matemati£ke formule u MathJax formatu")
("export mathematical formulas as MathML" "izvezi matemati£ke formule u MathML formatu")
("export selected entries" "izvoz odabranih upisa")
("export selection" "izvezi selekciju")
("export selections as" "izvezi selekcije kao")
("export selection as image" "izvezi selekciju kao sliku")
("export sessions" "izvezi sesije")
("export to BibTeX file" "izvoz u BibTeX datoteku")
("exported bibliographic entries" "izvezeni bibliografski upisi")
("exported bibliographic references" "izvezene bibliografske reference")
("extend" "produlji")
("extend or normal" "produlji ili normalno")
("extended" "produljeno")
("extensible left arrow" "produljena strelica lijevo")
("extensible right arrow" "produljena strelica desno")
("extern" "vanjski")
("external" "vanjski")
("extra" "ekstra")
("extra branch" "dodatni ogranak")
("extra interline space" "dodatni razmak meu retcima")
("extra name" "dodatni naziv")
("extract" "izdvoji")
("extract format" "izdvoji format")
("extract style file" "izdvoji stilsku datoteku")
("extract style package" "izdvoji stilski paket")
("extras" "dodaci")
("factor" "faktor")
("fade" "izblijedi")
("fade in" "izblijediti")
("fade out" "izblijediti")
("failed to" "neuspje²no")
("family" "familija")
("fast" "brzo")
("fast decrease" "brzo smanjenje")
("fast environments" "brza okruºenja")
("fast increase" "brzo pove¢avanje")
("february" "velja£a")
("field reference" "referenca na polje")
("fifth" "peto")
("figure" "slika")
("file" "datoteka")
("file name" "naziv datoteke")
("file not found" "datoteka nije pronaena")
("file saved" "datoteka je pohranjena")
("fill color" "boja ispunjavanja")
("fill out" "popuni")
("filter" "filter")
("find file" "pronai datoteku") 
("find next match" "pronai sljede¢e podudaranje")
("find text" "pronai tekst")
("finished collecting symbols documentation" "prikupljanje dokumentacije za simbole je zavr²eno")
("finnish" "finski")
("first" "prvo")
("first chunk" "prvi komad")
("first contact" "prvi kontakt")
("first difference" "prvo razlikovanje")
("first error" "prva pogre²ka")
("first field" "prvo polje")
("first indentation" "prva uvlaka")
("first item" "prva alineja")
("first occurrence" "prvo pojavljivanje")
("first page" "prva stranica")
("first similar" "prvo sli£no")
("first start" "prvi po£etak")
("fit" "prilagodi")
("fit to height" "prilagodi visini")
("fit to screen" "prilagodi veli£ini zaslona")
("fit to screen width" "prilagodi ²irini zaslona")
("fit to width" "prilagodi ²irini")
("five columns" "pet stupaca")
("fix broken citations" "popravi neispravne citate")
("fix broken references" "popravi neispravne reference")
("fix duplicate labels" "popravi dvostruke oznake")
("fixed" "fiksno")
("flag is off" "zastavica je isklju£ena")
("flag is on" "zastavica je uklju£ena")
("flat" "spljo²teno")
("flatten" "spljo²ti")
("flexibility" "fleksibilnost")
("flexibility factor for vertical spacing" "faktor fleksibilnosti vertikalnog razmicanja")
("float" "plovak")
("floating algorithm" "plutaju¢i algoritam")
("floating figure" "plutaju¢a slika")
("floating object" "plutaju¢i objekt")
("floating phantom" "plutaju¢i fantom")
("floating table" "plutaju¢a tablica")
("floral1" "cvjetno 1")
("floral2" "cvjetno 2")
("focus" "fokus")
("focus balloon" "obla£i¢ za fokus")
("focus dependent icons" "ikone ovisne o fokusu")
("fold" "preklop")
("fold all" "preklopi sve")
("fold all fields" "preklopi sva polja")
("fold back" "preklopi natrag")
("fold input field" "preklopi polje unosa")
("folded" "preklopljeno")
("follow external links" "slijedi vanjske poveznice")
("follow inverse links" "slijedi inverzne poveznice")
("font" "font")
("font base size" "osnovna veli£ina slova")
("font dpi" "DPI fonta")
("font effects" "efekti fonta")
("font family" "familija fonta")
("font name" "naziv fonta")
("font selector" "odabir fonta")
("font series" "vrsta fonta")
("font shape" "oblik fonta")
("font size" "veli£ina fonta")
("font type" "tip fonta")
("font variant" "varijanta fonta")
("fonts" "fontovi")
("footer" "podnoºje")
("footnote" "fusnota")
("for" "for")
("for each" "for each")
("force" "sila")
("force reloading of translations" "nametni ponovno u£itavanje prijevoda")
("foreground" "prednji plan")
("foreign" "strani")
("format" "oblikovanje")
("formatted and structured output" "uobli£eni i strukturirani izlaz")
("formatted date" "uobli£eni datum")
("formatting" "oblikovanje")
("formula" "formula")
("formula style" "stil formule")
("forward" "naprijed")
("forward replace" "zamijeni naprijed")
("forward search" "traºi naprijed")
("four columns" "£etiri stupca")
("four dots" "£etiri to£kice")
("fourth" "£etvrto")
("fraction" "razlomak")
("fraktur" "Fraktur")
("frame" "okvir")
("frame color" "boja okvira")
("frame effect" "efekt okvira")
("frame hpadding" "vodoravna ispuna okvira")
("frame picture" "slika okvira")
("frame thickness" "debljina okvira")
("frame vpadding" "vertikalna ispuna okvira")
("frames with shadows" "osjen£ani okviri")
("framed" "uokvireno")
("framed input fields" "uokvirena polja unosa")
("framed programs" "uokvireni programi")
("framed theorems" "uokvireni teoremi")
("framed title" "uokvireni naslov")
("french" "francuski")
("frequency" "frekvencija")
("frequencies" "frekvencije")
("from" "od")
("from center" "od sredine")
("front matter" "uvodni dio")
("full" "cjelovito")
("full author list" "cjeloviti popis autora")
("full manuals" "cjeloviti priru£nici")
("full name" "puni naziv")
("full screen mode" "cjelozaslonski na£in")
("function" "funkcija")
("function approximation" "aproksimacija funkcija")
("functional" "funkcionalno")
("further customization" "daljnja prilagodba")
("future changes" "budu¢e promjene")
("gap" "praznina")
("garbage collection" "skupljanje otpada")
("gaussian" "gaussovski")
("gaussian blur" "gaussovsko zamagljenje")
("generated LaTeX document contains no errors" "generirani LaTeX dokument ne sadrºi pogre²ke")
("generated field" "generirano polje")
("generating index" "generiranje kazala")
("generating manual" "gereriranje priru£nika")
("geometry" "geometrija")
("get arity" "dobivanje veli£ine n-torke")
("get label" "dobivanje oznake")
("get list with remote versions" "Lista s udaljenim ina£icama")
("gnaw" "oglodaj")
("gnawed" "oglodano")
("gnawed strength" "ja£ina glodanja")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs ne uklju£uje nikakav oblik pravnog jamstva")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs potpada pod op¢u GNU javnu licencu")
("gcd" "nzd")
("general" "op¢e")
("general architecture of TeXmacs" "op¢a arhitektura TeXmacsa")
("general negation" "op¢a negacija")
("general note" "op¢a bilje²ka")
("generating font file" "generiranje datoteke fonta")
("generic" "generi£ki stil")
("generic input color" "boja unesenog teksta")
("generic prompt color" "boja oznake polja")
("geometry" "geometrija")
("georgian" "gruzijski")
("german" "njema£ki")
("get arity" "dohvati veli£inu n-torke")
("get label" "dohvati oznaku")
("get list with remote versions" "dohvati listu s udaljenim ina£icama")
("getting started" "po£etak rada")
("global log" "globalni zapisnik")
("global status" "globalni status")
("glossary" "pojmovnik")
("glossary entry" "upis u pojmovniku")
("glue" "ljepilo")
("glue decorations" "slijepi ukrase")
("glue multiple spaces" "slijepi vi²estruke razmake")
("glyph" "glif")
("glyphs" "glifovi")
("gnuPG command" "naredba gnuPG")
("gnuPG error: buffer encryption failed" "gnuPG pogre²ka: ²ifriranje spremnika nije uspjelo")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG pogre²ka: ne mogu prona¢i odgovaraju¢i tajni klju£ za de²ifriranje")
("gnuPG key" "gnuPG klju£")
("gnuPG requires name and email to have at least 5 characters" "gnuPG zahtijeva da ime i e-adresa sadrºe najmanje 5 znakova")
("go" "idi")
("go to anchor" "idi na sidro")
("go to anchor or footnote" "idi na sidro ili fusnotu")
("go to first similar tag" "idi na prvo sli£no okruºenje")
("go to float" "idi na plutaju¢i objekt")
("go to last similar tag" "idi na posljednje sli£no okruºenje")
("go to next similar tag" "idi na sljede¢e sli£no okruºenje")
("go to previous similar tag" "idi na prethodno sli£no okruºenje")
("go to section" "idi na odjeljak")
("gothic" "goti£ko")
("gradient" "gradijent")
("grain" "zrno")
("granite" "granit")
("graph theory" "teorija grafova")
("graphical effects" "grafi£ki efekti")
("graphical interface" "grafi£ko su£elje")
("graphical interface font scale" "skaliranje fonta grafi£kog su£elja")
("graphical overlays" "grafi£ka prekrivanja")
("graphical slides and overlays" "grafi£ki slajdovi i prekrivanja")
("graphics" "grafika")
("graphics geometry" "geometrija grafike")
("graphics grids" "grafi£ke mreºe")
("grave" "te²ko")
("greater" "ve¢e")
("greater or equal" "ve¢e ili jednako")
("greek" "gr£ki")
("greek letter" "gr£ko slovo")
("green" "zeleno")
("grey" "sivo")
("greyed" "posivljeno")
("grid" "mreºa")
("grid curves" "krivulje mreºe")
("grid lines" "linije mreºe")
("grid points" "to£ke mreºe")
("grid-curve intersections" "sjeci²ta mreºe i krivulje")
("group" "grupiraj")
("group of objects" "grupa objekata")
("group/ungroup" "(raz)grupiraj")
("grouped" "grupirano")
("guarantee transparent source tracking" "garantiraj transparentno pra¢enje izvora")
("h modifier" "modifikator H")
("half" "pola")
("half wide" "polu²iroko")
("hand drawn" "nacrtano rukom")
("handwritten" "pisano rukom")
("hanging theorems" "vise¢i teoremi")
("happy typing" "sretno tipkanje")
("has been aborted" "je prekinut")
("has completed its task" "je obavio svoju zada¢u")
("hat" "kapica")
("header" "zaglavlje")
("header and footer" "zaglavlje i podnoºje")
("header bars" "zaglavne trake")
("headers" "zaglavlja")
("heat" "toplina")
("hebrew" "hebrejski")
("height" "visina")
("height is exactly the specified height" "visina je to£no jednaka specificiranoj")
("height is maximum of specified height and box height" "visina je jednaka ve¢oj izmeu specificirane visine i visine kutije")
("height is minimum of specified height and box height" "visina je jednaka manjoj izmeu specificirane visine i visine kutije")
("height magnification" "pove¢anje visine")
("help" "pomo¢")
("help balloon" "obla£i¢ za pomo¢")
("help me" "pomozi mi")
("help us" "pomozi nam")
("help with" "pomo¢ za")
("here" "ovdje")
("hidden" "skriveno")
("high resolution screen settings" "postavke zaslona visoke razlu£ivosti")
("high resolution settings" "postavke visoke razlu£ivosti")
("highlight errors" "posvijetli pogre²ke")
("history" "povijest")
("home" "home")
("homepage" "ku¢na stranica")
("homoglyph substitutions" "homoglifne zamjene")
("horizontal" "vodoravno")
("horizontal alignment" "vodoravno poravnavanje")
("horizontal cell alignment" "vodoravno poravnavanje ¢elije")
("horizontal cell padding" "vodoravna ispuna ¢elije")
("horizontal collapse distance" "vodoravna udaljenost kolapsa")
("horizontal ink separation" "vodoravno razdvajanje crnila")
("horizontal padding" "vodoravno ispunjavanje")
("horizontal part" "vodoravni dio")
("horizontal position" "vodoravni poloºaj")
("horizontal space" "vodoravni razmak")
("horizontal table alignment" "vodoravno poravnavanje tablice")
("horizontally align cell to the base" "vodoravno poravnavanje ¢elije na osnovicu")
("horizontally center the cell" "vodoravno centriranje ¢elije")
("how much longer may pages become" "koliko dulje mogu biti stranice")
("how much shorter may pages become" "koliko kra¢e mogu biti stranice")
("html" "HTML")
("huge" "golemo")
("hungarian" "maarski")
("hybrid command" "hibridna naredba")
("hyperlink" "hiperpoveznica")
("hyphenate as" "prelomi rije£i kao") 
("hyphenation" "prijelom rije£i")
("hyperbolic functions" "hiperbolne funkcije")
("ice" "led")
("icelandic" "islandski")
("icon" "ikona")
("identifier" "identifikator")
("idle" "besposlen")
("if" "if")
("if hyphenated" "ako je rije£ prelomljena")
("ignore" "zanemari")
("impact" "utjecaj")
("image" "slika")
("image links" "poveznice sa slikama")
("implementation" "implementacija")
("import" "uvoz")
("import bibliography" "uvezi popis literature")
("import database entry" "uvezi upis u bazi podataka")
("import entries in buffer" "uvezi upise u spremnik")
("import entry" "uvezi upis")
("import file" "uvezi datoteku")
("import font" "uvezi font")
("import from BibTeX file" "uvoz iz BibTeX datoteke")
("import selected database entries" "uvoz odabranih upisa u bazi podataka")
("import selected entries" "uvoz odabranih upisa")
("import selections as" "uvezi selekcije kao")
("import sessions" "uvezi sesije")
("import sophisticated objects as pictures" "uvezi sofisticirane objekte kao slike")
("imported bibliographic entries" "uvezeni bibliografski upisi")
("improving the current implementation" "pobolj²avanje sada²nje implementacije")
("in" "u")
("in popup windows" "u sko£nim prozorima")
("inactive" "neaktivno")
("inanimated" "neanimirano")
("inch" "in£")
("inches" "in£a")
("include" "uklju£i")
("include a document" "uklju£i dokument")
("include file" "uklju£i datoteku")
("inclusion into TeXmacs" "uklju£ivanje u TeXmacs")
("inclusions" "uklju£enja")
("incomplete entries found to be filled out" "pronaeni su nepotpuni upisi koje je potrebno ispuniti")
("increase size" "pove¢aj")
("indent" "uvlaka")
("indent indentation" "uvla£enje uvlake")
("indent paragraphs" "uvla£enje odlomaka")
("indent step" "korak uvla£enja")
("indentation" "uvla£enje")
("indentation flag" "postavke uvla£enja")
("index" "kazalo")
("index enabled" "kazalo omogu¢eno")
("index entry" "upis u kazalu")
("index level" "nivo kazala")
("index prefix" "prefiks kazala")
("indication" "naznaka")
("inflate" "napuhni")
("informative flags" "informativne zastavice")
("initialize" "inicijalizacija")
("initials" "inicijali")
("inner" "unutarnje")
("inner bottom" "unutarnje dno")
("inner left" "unutarnje lijevo")
("inner right" "unutarnje desno")
("inner top" "unutarnji vrh")
("ink here" "tinta ovdje")
("ink in" "tinta u")
("ink out" "tinta van")
("inline" "unutar retka")
("inline args" "argumenti unutar retka")
("inline arguments" "argumenti unutar retka")
("inline code" "programski kod unutar retka")
("inline formula" "formula unutar retka")
("input" "unos")
("input command" "naredba za unos")
("input field" "polje unosa")
("input mode" "na£in unosa")
("input options" "mogu¢nosti unosa")
("insert" "umetni")
("insert last name" "umetni prezime")
("insert plain text" "umetni obi£an tekst")
("insert Pr" "umetni Pr")
("insert a TeXmacs symbol" "umetni TeXmacs simbol")
("insert a big operator" "umetni veliki operator")
("insert a binary operation" "umetni binarnu operaciju")
("insert a binary relation" "umetni binarnu relaciju")
("insert a blackboard bold character" "umetni dvostruki podebljani znak")
("insert a bold calligraphic character" "umetni podebljani kaligrafski znak")
("insert a bold character" "umetni podebljani znak")
("insert a calligraphic character" "umetni kaligrafski znak")
("insert a computer program" "umetni ra£unalni program")
("insert a condition" "umetni uvjet")
("insert a control flow instruction" "umetni instrukciju kontrole tijeka")
("insert a fraction" "umetni razlomak")
("insert a fraktur character" "umetni fraktur slovo")
("insert a gap" "umetni prazninu")
("insert a greek character" "umetni gr£ko slovo")
("insert a large left delimiter" "umetni veliki lijevi odjelnik")
("insert a large right delimiter" "umetni veliki desni odjelnik")
("insert a large separator" "umetni veliki razdjelnik")
("insert a left subscript" "umetni lijevi indeks")
("insert a link" "umetni poveznicu")
("insert a list" "umetni popis")
("insert a miscellaneous symbol" "umetanje raznih simbola")
("insert a multiple choice" "umetni vi²estruki izbor")
("insert a negation" "umetni negaciju")
("insert a new branch" "umetni novi ogranak")
("insert a new item" "umetni novu alineju")
("insert a note or a floating object" "umetni bilje²ku ili plutaju¢i objekt")
("insert a numerical operation" "umetni numeri£ku operaciju")
("insert a personal macro" "umetni vlastiti makro")
("insert a picture" "umetni sliku")
("insert a prominent piece of text" "umetni istaknuti dio teksta")
("insert a question" "umetni pitanje")
("insert a root" "umetni korijen")
("insert a script" "umetni indeks")
("insert a section block" "umetni blok odjeljka")
("insert a square root" "umetni kvadratni korijen")
("insert a table" "umetni tablicu")
("insert a table or a matrix" "umetni tablicu ili matricu")
("insert a textual operation" "umetni tekstualnu operaciju")
("insert a textual operator" "umetni tekstualni operator")
("insert a wide symbol above" "umetni ²iroki simbol iznad")
("insert a wide symbol below" "umetni ²iroki simbol ispod")
("insert above" "umetni iznad")
("insert abstract" "umetni saºetak")
("insert an" "umetni")
("insert an accent" "umetni naglasak")
("insert an answer" "umetni odgovor")
("insert an arrow" "umetni strelicu")
("insert an enunciation" "umetni proglas")
("insert an environment" "umetni okruºenje")
("insert an n" "umetni n")
("insert an operation on tuples" "umetni operaciju na n-torkama")
("insert annotation" "umetni pribilje²ku")
("insert appendix" "umetni dodatak")
("insert arccos" "umetni arkus kosinus")
("insert arcsin" "umetni arkus sinus")
("insert arctan" "umetni arkus tangens")
("insert arg" "umetni argument")
("insert argument" "umetni argument")
("insert argument after" "umetni argument iza")
("insert argument before" "umetni argument ispred")
("insert author" "umetni ime autora")
("insert automatically generated content" "umetni automatski generiran sadrºaj")
("insert below" "umetni ispod")
("insert big contour integral" "umetni veliki operator krivuljnog integrala")
("insert big coproduct" "umetni veliki operator koprodukta")
("insert big direct sum" "umetni veliki operator izravne sume")
("insert big dotted point" "umetni veliki operator mnoºenja po £lanovima")
("insert big integral" "umetni veliki operator integrala")
("insert big intersection" "umetni veliki operator presjeka")
("insert big logical and" "umetni veliki operator konjunkcije")
("insert big logical or" "umetni veliki operator disjunkcije")
("insert big product" "umetni veliki operator mnoºenja")
("insert big square union" "umetni veliki operator £etvrtaste unije")
("insert big summation" "umetni veliki operator zbroja")
("insert big tensor product" "umetni veliki operator tenzorskog umno²ka")
("insert big union" "umetni veliki operator unije")
("insert big union sum" "umetni veliki operator zbrajanja po uniji")
("insert big vertical space" "umetni veliki vertikalni preskok")
("insert chapter" "umetni poglavlje")
("insert column" "umetni stupac")
("insert column to the left" "umetni stupac slijeva")
("insert column to the right" "umetni stupac zdesna")
("insert copyright and license information" "umetni podatke o autorskim pravima i licenci")
("insert cos" "umetni kosinus")
("insert cosh" "umetni kosinus hiperbolni")
("insert cot" "umetni kotangens")
("insert coth" "umetni kotangens hiperbolni")
("insert csc" "umetni kosekans")
("insert deg" "umetni funkciju deg")
("insert det" "umetni funkciju det")
("insert dim" "umetni funkciju dim")
("insert dollar" "umetni znak dolara")
("insert equation" "umetni jednadºbu")
("insert executable markup" "umetni izvr²nu slagarsku instrukciju")
("insert exp" "umetni funkciju exp")
("insert explanatory item" "umetni obja²njenje")
("insert field above" "umetni polje iznad")
("insert field below" "umetni polje ispod")
("insert fields" "umetni polja")
("insert footnote" "umetni fusnotu")
("insert formula" "umetni formulu")
("insert gcd" "umetni funkciju nzd")
("insert hom" "umetni funkciju hom")
("insert horizontal interword space" "umetni vodoravni razmak meu rije£ima")
("insert image" "umetni sliku")
("insert inactive markup" "umetni neaktivnu slagarsku instrukciju")
("insert inf" "umetni simbol inf")
("insert input field above" "umetni unosno polje iznad")
("insert input field below" "umetni unosno polje ispod")
("insert ker" "umetni jezgru")
("insert large delimiters" "umetni velike odjelnike")
("insert left" "umetni slijeva")
("insert lg" "umetni funkciju lg")
("insert lim" "umetni limes")
("insert liminf" "umetni limes inferior")
("insert limsup" "umetni limes superior")
("insert ln" "umetni prirodni logaritam")
("insert log" "umetni logaritam")
("insert macro" "umetni makro")
("insert mathematics" "umetni matemati£ki tekst")
("insert max" "umetni maksimum")
("insert medium horizontal space" "umetni srednji vodoravni razmak")
("insert medium vertical space" "umetni srednji vertikalni razmak")
("insert min" "umetni funkciju min")
("insert missing invisible operators" "umetni nevidljive operatore koji nedostaju")
("insert more names" "umetni vi²e imena")
("insert particle" "umetni £esticu")
("insert negative horizontal space" "umetni negativni vodoravni razmak")
("insert new item or number" "umetni novu alineju ili broj")
("insert new rows or columns" "umetni nove retke ili stupce")
("insert or delete rows or columns" "umetni/ukloni retke ili stupce")
("insert overlay after" "umetni prekrivanje iza")
("insert overlay before" "umetni prekrivanje prije")
("insert right" "umetni zdesna")
("insert row" "umetni redak")
("insert row above" "umetni redak iznad")
("insert row below" "umetni redak ispod")
("insert sec" "umetni sekans")
("insert section" "umetni odjeljak")
("insert sharp" "umetni povisilicu")
("insert similar above" "umetni sli£no iznad")
("insert similar below" "umetni sli£no ispod")
("insert similar block above" "umetni sli£an blok iznad")
("insert similar block below" "umetni sli£an blok ispod")
("insert sin" "umetni sinus")
("insert sinh" "umetni sinus hiperbolni")
("insert small horizontal space" "umetni mali vodoravni razmak")
("insert small vertical space" "umetni mali vertikalni razmak")
("insert structural markup" "umetni strukturnu slagarsku instrukciju")
("insert subsection" "umetni pododjeljak")
("insert subsubsection" "umetni podpododjeljak")
("insert subtable" "umetni podtablicu")
("insert sup" "umetni funkciju sup")
("insert symbol documentation" "umetni dokumentaciju za simbol")
("insert tan" "umetni tangens")
("insert tanh" "umetni tangens hiperbolni")
("insert template" "umetni predloºak")
("insert text field" "umetni tekstualno polje")
("insert text field above" "umetni tekstualno polje iznad")
("insert text field below" "umetni tekstualno polje ispod")
("insert thick horizontal space" "umetni debeo vodoravan razmak")
("insert title" "umetni naslov")
("insert title after name" "umetni naslov iza imena")
("insert user interface related markup" "umetni oznaku vezanu za korisni£ko su£elje")
("insert value" "umetni vrijednost")
("inserting control points" "umetanje kontrolnih to£aka")
("inside mathematics" "u matemati£kom na£inu")
("integer arithmetic" "aritmetika cijelih brojeva")
("integrate" "integriranje")
("interactive command" "interaktivna naredba")
("interactive questions" "interaktivna pitanja")
("intercharacter compression" "meuznakovno sabijanje")
("intercharacter stretching" "meuznakovno rastezanje")
("interfacing" "su£eljavanje")
("interfacing TeXmacs with other systems" "su£eljavanje TeXmacsa i drugih sustava")
("interjection" "ubacivanje")
("interline separation" "razdvajanje redaka")
("interline space" "razmak meu retcima")
("internationalization" "meunarodnost")
("interparagraph space" "razmak meu odlomcima")
("interpolation" "interpolacija")
("interrupt execution" "prekini izvr²avanje")
("interrupted" "prekinuto")
("introduction" "uvod")
("invalid multi-paragraph selection" "nevaºe¢i odabir vi²e odlomaka")
("invalid paste of text into a formula" "nevaºe¢e lijepljenje teksta u formulu")
("invalid renaming" "nevaºe¢e preimenovanje")
("invert" "invertiranje")
("inverted breve" "obrnuti breve")
("invisible" "nevidljivo")
("invisible citation" "nevidljivi citat")
("invisible ending" "nevidljivo zavr²avanje")
("invisible newline" "nevidljivi prijelaz u novi redak")
("invisible opening" "nevidljivo otvaranje")
("irish" "irski")
("is running" "je pokrenuta")
("is tuple" "je n-torka")
("ispell does not respond" "ispell ne odgovara")
("ispell is already busy" "ispell je ve¢ zauzet")
("italian" "talijanski")
("italic" "kurziv")
("italic right" "desni kurziv")
("item" "alineja")
("item hsep" "vodoravno odvajanje alineje")
("item vsep" "vertikalno odvajanje alineje")
("itemize" "alineje")
("itemize arrow" "alineje strelice")
("itemize dash" "alineje crtice")
("itemize dot" "alineje to£ke")
("itemize levels" "broj razina alineja")
("itemize minus" "alineje crtice")
("january" "sije£anj")
("japanese" "japanski")
("java Source Code" "izvorni Java kod")
("join selected cells" "spoji ozna£ene ¢elije")
("journal" "£asopis")
("julia source code" "izvorni Julia kod")
("july" "srpanj")
("jump in" "usko£i")
("june" "lipanj")
("junior" "mlai")
("justified" "obostrano poravnato")
("justify" "obostrano poravnavanje")
("justify text" "obostrano poravnavanje teksta")
("keep evaluated expressions" "zadrºi evaluirane izraze")
("keep local" "zadrºi lokalno")
("keep remote" "zadrºi daljinsko")
("keep track of source code" "prati izvorni kod")
("keep unfolded" "zadrºi razvijeno")
("key" "klju£")
("keyboard" "tipkovnica")
("keyboard configuration" "konfiguracija tipkovnice")
("keyboard equivalent" "ekvivalentna tipka")
("keyboard modifiers" "tipke modifikatori")
("keyboard shortcut" "pre£ica tipkovnice")
("keymaps" "rasporedi tipki")
("keys" "klju£evi")
("keyword" "klju£na rije£")
("keywords" "klju£ne rije£i")
("kill" "ubij")
("known bugs" "poznate pogre²ke u programu")
("korean" "korejski")
("label" "oznaka")
("landscape" "pejzaº")
("language" "jezik")
("laptop presentations" "prezentacije na laptopu")
("large" "veliko")
("large brackets" "velike zagrade")
("large cells" "velike ¢elije")
("large closing bracket" "velika zatvorena zagrada")
("large delimiter" "veliki odjelnik")
("large displayed" "veliko za prikazivanje")
("large displayed fraction" "veliki razlomak za prikazivanje")
("large opening bracket" "velika otvorena zagrada")
("large separator" "veliki razdjelnik")
("large padding above" "velika ispuna iznad")
("large padding below" "velika ispuna ispod")
("large tables" "velike tablice")
("last" "posljednje")
("last check" "posljednja provjera")
("last difference" "posljednje razlikovanje")
("last error" "posljednja pogre²ka")
("last field" "posljednje polje")
("last item nr" "redni broj posljednjeg unosa")
("last occurrence" "posljednje pojavljivanje")
("last page" "posljednja stranica")
("last similar" "posljednje sli£no")
("latex" "LaTeX")
("latex command" "LaTeX naredba")
("latin" "latini£no")
("layout" "prijelom")
("lcm" "nzm")
("lecture note" "bilje²ka s predavanja")
("left" "lijevo")
("left aligned" "poravnato nalijevo")
("left arrow" "strelica lijevo")
("left axis" "lijeva os")
("left baseline" "lijeva osnovica")
("left border" "lijevi rub")
("left bottom" "lijevo dno")
("left cell border" "lijevi rub ¢elije")
("left cell padding" "lijeva ispuna ¢elije")
("left center" "lijeva sredina")
("left click: add point; Right click: undo" "lijevi klik: dodaj to£ku; desni klik: poni²ti")
("left click: finish; Right click: undo" "lijevi klik: zavr²i; desni klik: poni²ti")
("left click: new object" "lijevi klik: novi objekt")
("left click: operate" "lijevi klik: djeluj")
("left down" "lijevo dolje")
("left margin" "lijeva margina")
("left on even pages" "lijevo na parnim stranicama")
("left padding" "lijeva ispuna")
("left prime" "lijevi prim")
("left slanted" "nako²eno u lijevo")
("left subscript" "lijevi indeks")
("left superscript" "lijevi eksponent")
("left surrounding" "lijevo naokolo")
("left table border" "lijevi rub tablice")
("left table padding" "lijeva ispuna tablice")
("left top" "lijevi vrh")
("left up" "lijevo gore")
("left-right arrow" "strelica lijevo-desno")
("leftwards" "prema lijevo")
("legal" "legal")
("lemma" "lema")
("length" "duljina")
("less" "manje")
("less or equal" "manje ili jednako")
("let the environment float" "pusti da okruºenje pliva")
("letter" "dopis")
("letter header" "zaglavlje dopisa")
("letter date" "datum dopisa")
("license" "licenca")
("light" "lako")
("light grey" "svijetlosivo")
("limitations" "ograni£enja")
("limit" "granica")
("limits" "granice")
("line" "crta")
("line arrows" "strelice na krajevima crte")
("line break" "prijelom retka")
("line breaking" "prelamanje redaka")
("line count" "broj redaka")
("line dashes" "na£in iscrtavanja")
("line stretch" "rastezanje retka")
("line style" "stil crte")
("line width" "²irina crte")
("line wrapping" "omatanje redaka")
("linear 2D" "linearno 2D")
("linear algebra" "linearna algebra")
("lines around" "odijeljeno crtama")
("link" "poveznica")
("link image" "poveºi sliku")
("link image and copies as" "poveºi sliku i kopije kao")
("link image as" "poveºi sliku kao")
("link mode" "na£in poveznice")
("link to URL" "poveznica na URL")
("linking tool" "alat za povezivanje")
("list" "popis")
("list of figures" "popis slika")
("list of tables" "popis tablica")
("live" "uºivo")
("live input-output" "ulaz-izlaz uºivo")
("load" "u£itaj")
("load LaTeX file" "u£itaj LaTeX datoteku")
("load TeX file" "u£itaj TeX datoteku")
("load TeXmacs file" "u£itaj TeXmacs datoteku")
("load TeXmacs style file" "u£itaj TeXmacs stilsku datoteku")
("load a file" "u£itaj datoteku")
("load buffer" "u£itaj spremnik")
("load file" "u£itaj datoteku")
("load help file" "u£itaj datoteku za pomo¢")
("load html file" "u£itaj HTML datoteku")
("load image" "u£itaj sliku")
("load in new window" "u£itaj u novom prozoru")
("load latex file" "u£itaj LaTeX datoteku")
("load more recent autosave file" "u£itaj nedavno automatski pohranjenu datoteku")
("load remote file" "u£itaj udaljenu datoteku")
("load tex file" "u£itaj TeX datoteku")
("load verbatim file" "u£itaj doslovnu datoteku")
("loaded" "u£itano")
("loading" "u£itavanje")
("local entries" "lokalni upisi")
("loci" "lokusi")
("locus" "lokus")
("locus color" "boja lokusa")
("locus rendering" "renderiranje lokusa")
("logarithm" "logaritam")
("logarithmic" "logaritamski")
("logarithmic base" "baza logaritma")
("logarithms" "logaritmi")
("logging in" "prijavljivanje")
("logical and" "logi£ko i")
("logical implication" "logi£ka implikacija")
("logical not" "logi£ka negacija")
("logical or" "logi£ko ili")
("login" "prijava")
("logout" "odjava")
("long" "duga£ko")
("long macro" "duga£ki makro")
("long text" "duga£ki tekst")
("look and feel" "izgled su£elja")
("look for more fonts" "potraºi vi²e fontova")
("look up" "traºi")
("loops" "petlje")
("lower border" "donji rub")
("m modifier" "modifikator M")
("macro" "makro")
("macro argument" "argument za makro")
("macro definition" "definicija makroa")
("macro editor" "ureivanje makroa")
("macro name" "naziv makroa")
("macros" "makroi")
("magenta" "purpurnocrveno")
("magic" "£arolija")
("magnetic field" "magnetsko polje")
("magnification" "pove¢anje")
("magnified" "pove¢ano")
("magnify horizontally" "vodoravno pove¢anje")
("magnify vertically" "vertikalno pove¢anje")
("main" "glavno")
("main document font" "glavni font dokumenta")
("main document style" "glavni stil dokumenta")
("main icon bar" "glavna traka ikona")
("main presentation style" "glavni stil prezentacije")
("major changes" "glavne promjene")
("make a letter environment" "na£ini okruºenje za fontove")
("make a multi-slide presentation" "na£ini prezentaciju s vi²e slajdova")
("make a page insertion" "uvrsti stranicu")
("make a subscript" "na£ini indeks")
("make a superscript" "na£ini eksponent")
("make acute" "zao²tri")
("make bar" "na£ini crtu")
("make check" "na£ini provjeru")
("make floating" "u£ini da pluta")
("make fraction" "na£ini razlomak")
("make grave" "oteºaj")
("make hat" "na£ini kapicu")
("make label" "na£ini oznaku")
("make link" "na£ini poveznicu")
("make negation" "na£ini negaciju")
("make non floating" "u£ini da ne pluta")
("make opaque" "u£ini neprozirnim")
("make page reference" "na£ini referencu na stranicu")
("make reference" "na£ini referencu")
("make slides" "na£ini slajdove")
("make square root" "na£ini kvadratni korijen")
("make tilde" "na£ini tildu")
("make title" "na£ini naslov")
("make transparent" "u£ini prozirnim")
("make vector" "na£ini vektor")
("making donations" "doniranje")
("manila paper" "manilski papir")
("manual" "priru£nik")
("map arguments" "mapiraj argumente")
("map to" "mapiraj na")
("march" "oºujak")
("marginal note" "bilje²ka na margini")
("margins" "margine")
("margins as on paper" "margine na papiru")
("margins from width" "margine od ²irine")
("margins on paper" "margine na papiru")
("margins on screen" "margine na zaslonu")
("marked" "obiljeºeno")
("marker" "marker")
("markup" "ozna£avanje")
("mass" "masa")
("master" "master")
("master file" "master datoteka")
("mastersthesis" "magistarski rad")
("material" "materijal")
("math" "matemati£ki")
("math Extra" "ekstra matematika")
("math font" "matemati£ki font")
("math font family" "familija matemati£kog fonta")
("math font series" "vrsta matemati£kog fonta")
("math font shape" "oblik matemati£kog fonta")
("math Letters" "matemati£ka slova")
("math swell" "zadebljanje matemati£kog teksta")
("math Symbols" "matemati£ki simboli")
("mathematical" "matemati£ki")
("mathematical and customized input" "matemati£ki i prilagoeni unos")
("mathematical font" "matemati£ki font")
("mathematical formulas" "matemati£ke formule")
("mathematical input" "unos matemati£kog teksta")
("mathematical typesetting" "slaganje matemati£kog teksta")
("mathematics" "matematika")
("matrices" "matrice")
("matrix" "matrica")
("matrix factorization" "faktorizacija matrica")
("maximal" "maksimalno")
("maximal cell height" "maksimalna visina ¢elije")
("maximal cell width" "maksimalna ²irina ¢elije")
("maximal clustering" "maksimalno grupiranje")
("maximal table width" "maksimalna ²irina tablice")
("maximal number of columns" "maksimalni broj stupaca")
("maximal number of rows" "maksimalni broj redaka")
("maximal table height" "maksimalna visina tablice")
("maximum" "maksimum")
("maximum mode" "na£in maksimuma")
("may" "svibanj")
("meander" "krivudavo")
("mean" "srednja vrijednost")
("median" "medijan")
("medieval" "srednjevjekovno")
("medium" "umjereno")
("medium skip" "umjereni preskok")
("meminfo" "informacije o memoriji")
("memory" "memorija")
("memory usage" "raspolaganje memorijom")
("menu" "izbornik")
("merge" "spoji")
("merge lines into paragraphs unless separated by blank lines" "poveºi retke u odlomke osim ako nisu odvojeni praznim retcima")
("messages" "poruke")
("messy" "neuredno")
("meta data" "meta podaci")
("meta key" "meta tipka")
("metadata" "metapodaci")
("metal" "metal")
("middle" "sredina")
("middle baseline" "sredi²nja osnovica")
("minimal" "minimalno")
("minimal cell height" "minimalna visina ¢elije")
("minimal cell width" "minimalna ²irina ¢elije")
("minimal line separation" "minimalno odvajanje redaka")
("minimal number of columns" "minimalan broj stupaca")
("minimal number of rows" "mimimalan broj redaka")
("minimal table height" "minimalna visina tablice")
("minimal table width" "minimalna ²irina tablice")
("minimum" "minimum")
("minimum mode" "na£in minimuma")
("minus" "minus")
("mirror" "zrcalo")
("misc" "razno")
("miscellaneous" "razno")
("miscellaneous features" "razna svojstva")
("missing" "nedostaje")
("mixed" "mije²ano")
("mod" "modulo")
("mode" "na£in")
("mode dependent icons" "ikone ovisne o na£inu")
("modifier" "modifikator")
("modify cell alignment" "modificiraj poravnavanje ¢elije")
("modify cell border" "modificiraj rub ¢elije")
("modify cell padding" "modificiraj ispunu ¢elije")
("modify cell size" "modificiraj veli£inu ¢elije")
("modify remote live document" "izmijeni udaljeni dokument uºivo")
("modify table border" "modificiraj rub tablice")
("modify table padding" "modificiraj ispunu tablice")
("module" "modul")
("module browser" "preglednik modula")
("mongolian" "mongolski")
("monospaced" "jednoliko razmaknuta slova")
("month" "mjesec")
("more information about GNU TeXmacs can be found in the Help->About menu" "vi²e podataka o GNU TeXmacsu moºe se prona¢i u izborniku Pomo¢->O programu")
("mosaic" "mozaik")
("motion" "kretanje")
("motion blur" "zamagljenje pokreta")
("mouse over balloon" "obla£i¢ ako je pokaziva£ iznad")
("mouse over object" "objekt ako je pokaziva£ iznad")
("move" "pomicanje")
("move down" "pomicanje prema dolje")
("move object" "pomicanje objekta")
("move objects" "pomicanje objekata")
("move over object on which to operate" "prijei preko objekta na kojem ¢e se raditi")
("move to the right when finished" "pomakni udesno nakon zavr²etka")
("move up" "pomicanje prema gore")
("multiline" "vi²elinijski")
("multiline input" "vi²elinijski unos")
("multiple choice" "vi²estruki izbor")
("multiple documents share window" "vi²e dokumenata u istom prozoru")
("multiple root" "vi²estruki korijen")
("multiplication" "mnoºenje")
("mutator tags" "promjenjiva okruºenja")
("my bibliographic database" "moja bibliografska baza podataka")
("my documents" "moji dokumenti")
("n-th" "n-ti")
("n-th root" "n-ti korijen")
("name" "naziv")
("name of bibliography" "naziv popisa literature")
("name of glossary" "naziv pojmovnika")
("name of index" "naziv kazala")
("name of list of figures" "naziv popisa slika")
("name of list of tables" "naziv popisa tablica")
("name of table of contents" "naziv sadrºaja")
("named" "pod nazivom")
("navigation options" "mogu¢nosti navigacije")
("negation" "negacija")
("never" "nikada")
("new" "novo")
("new account" "novi ra£un")
("new bibliography dialogue" "novi dijalog za popis literature")
("new buffer" "novi spremnik")
("new column" "novi stupac")
("new context macro" "novi kontekstualni makro")
("new document" "novi dokument")
("new double page" "nova dvostruka stranica")
("new double page before" "nova dvostruka stranica prije")
("new entry" "novi upis")
("new item" "nova alineja")
("new line" "novi redak")
("new locus" "novi lokus")
("new macro" "novi makro")
("new number" "novi broj")
("new page" "nova stranica")
("new page before" "nova stranica prije")
("new paragraph" "novi odlomak")
("new passphrase" "nova zaporka")
("new remote directory" "novi udaljeni direktorij")
("new remote file" "nova udaljena datoteka")
("new roman" "new roman")
("new row" "novi redak")
("new style fonts" "novi stilski fontovi")
("new style page breaking" "novi stil prijeloma stranica")
("new table" "nova tablica")
("new table macro" "novi tabelarni makro")
("new version" "nova ina£ica")
("new window" "novi prozor")
("newer version" "novija ina£ica")
("next" "sljede¢e")
("next chunk" "novi komad")
("next difference" "sljede¢e razlikovanje")
("next error" "sljede¢a pogre²ka")
("next field" "sljede¢e polje")
("next line" "sljede¢i redak")
("next occurrence" "sljede¢e pojavljivanje")
("next screen" "sljede¢i zaslon")
("next similar" "sljede¢e sli£no")
("no" "ne")
("no animation" "nema animacije")
("no changes need to be saved" "nema promjena koje je potrebno pohraniti")
("no clustering" "bez grupiranja")
("no completions" "bez dovr²avanja")
("no dictionary for" "nema rje£nika za")
("no errors have been corrected" "niti jedna pogre²ka nije ispravljena")
("no first indentation" "nema prve uvlake")
("no grid" "bez mreºe")
("no indentation" "ne uvla£i")
("no line break" "ne prelamaj redak")
("no matches found" "nema podudaranja")
("no matches found for" "nema podudaranja s")
("no more matches for" "nema vi²e podudaranja s")
("no more redo information available" "nemogu¢e je ponoviti")
("no more undo information available" "nemogu¢e je poni²titi")
("no multiple spaces" "bez vi²estrukih razmaka")
("no name" "bez naziva")
("no new public key in document" "nema novog javnog klju£a u dokumentu")
("no page break" "ne prelamaj stranicu")
("no page break after" "ne prelamaj stranicu nakon")
("no page break before" "ne prelamaj stranicu prije")
("no page numbers" "bez brojeva stranica")
("no parent" "nema roditelja")
("no selection" "nema selekcije")
("no spelling errors" "nema pravopisnih pogre²aka")
("no spelling errors found in text" "u tekstu nema pravopisnih pogre²aka")
("no spurious spaces" "bez laºnih razmaka")
("no style" "bez stila")
("none" "ni²ta")
("normal" "normalno")
("normal loci" "normalni lokusi")
("normal size" "normalna veli£ina")
("norwegian" "norve²ki")
("not" "ne")
("not allowed to remove home directory" "nije dopu²teno uklanjanje ku¢nog direktorija")
("not connected to server" "nema veze s posluºiteljem")
("not equal" "nije jednako")
("not found" "nije pronaeno")
("not yet implemented" "nije jo² implementirano")
("notation" "notacija")
("note" "bilje²ka")
("note inline" "bilje²ka unutar retka")
("notebook" "biljeºnica")
("november" "studeni")
("number" "broj")
("number of columns" "broj stupaca")
("number of polar steps" "broj koraka u polarnim koordinatama")
("number of subunit steps" "broj podjedini£nih koraka")
("number equation" "numeriraj jednadºbu")
("numbered" "numerirano")
("numbered equation" "numerirana jednadºba")
("numbered equations" "numerirane jednadºbe")
("numbering" "numeriranje")
("numerator" "brojnik")
("numeric" "broj£ano")
("numeric analysis" "numeri£ka analiza")
("numeric comma table" "numeri£ka tablica sa zarezom")
("numeric dot table" "numeri£ka tablica s to£kom")
("numeric spreadsheet" "numeri£ka prora£unska tablica")
("objectives" "ciljevi")
("oblique" "nako²eno")
("occurrences" "pojavljivanja")
("october" "listopad")
("odd page" "neparna stranica")
("odd page footer" "podnoºje neparne stranice")
("odd page header" "zaglavlje neparne stranice")
("odd page margin" "margina neparne stranice")
("odd page left margin" "lijeva margina neparne stranice")
("odd page right margin" "desna margina neparne stranice")
("odd page shift" "pomak neparne stranice")
("odd pages" "neparne stranice")
("of fingerprint" "od otiska")
("off" "isklju£eno")
("ok" "u redu")
("old english" "staroengleski")
("old slavonic" "staroslavenski")
("old style" "stari stil")
("old version" "stara ina£ica")
("older version" "starija ina£ica")
("on" "uklju£eno")
("on cells" "na ¢elijama")
("on columns" "na stupcima")
("on entire table" "na £itavoj tablici")
("on rows" "na retcima")
("on the footer" "u podnoºju")
("on your system and set it up from the \"Security\" tab" "u va²em sustavu i podesite ga s kartice \"Sigurnost\"")
("once" "jednom")
("one column" "jedan stupac")
("one error has been corrected" "jedna pogre²ka je ispravljena")
("one lower case letter, one non alpha-numeric symbol" "jedno malo slovo, jedan ne-alfanumeri£ki simbol")
("one numeric character, one upper case letter" "jedan numeri£ki znak, jedno veliko slovo")
("one spelling error has been corrected" "jedna pravopisna pogre²ka je ispravljena")
("online documentation" "dokumentacija na mreºi")
("online help" "pomo¢ na mreºi")
("only convert changes when re-importing" "pretvorba promjena samo kod ponovnog uvoza")
("only convert changes with respect to imported version" "pretvorba promjena isklju£ivo s obzirom na izvezenu ina£icu")
("only convert changes with respect to tracked version" "pretvorba promjena isklju£ivo s obzirom na pra¢enu ina£icu")
("only implemented for complete subtrees" "implementirano samo za kompletna podstabla")
("only inline tags" "samo okruºenja unutar retka")
("only keep folded" "sa£uvaj samo preklopljeno")
("only keep unfolded" "sa£uvaj samo razvijeno")
("only show semantic focus" "prikazuj samo semanti£ki fokus")
("opacity" "neprozirnost")
("open" "otvori")
("open a new buffer" "otvori novi spremnik")
("open bibliography" "otvori popis literature")
("open identities" "otvori identitete")
("open in new window" "otvori u novom prozoru")
("open mailbox" "otvori po²tanski sandu£i¢")
("open module browser" "otvori preglednik modula")
("open new window" "otvori novi prozor")
("open on errors" "otvori u slu£aju gre²ke")
("open on warnings" "otvori u slu£aju upozorenja")
("open symbol browser" "otvori preglednik simbola")
("open tool in separate window" "otvori alat u zasebnom prozoru")
("opening" "otvaranje")
("operation mode" "operativni na£in")
("operation on named selection" "operiranje na imenovanoj selekciji")
("operation on primary selection" "operiranje na primarnoj selekciji")
("operation on secondary selection" "operiranje na sekundarnoj selekciji")
("operation on ternary selection" "operiranje na tercijarnoj selekciji")
("optical" "opti£ko")
("optimization" "optimizacija")
("option" "mogu¢nost")
("optional branch" "opcionalni ogranak")
("options" "mogu¢nosti")
("or" "ili")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "ili unesi cjelovitu stazu do naredbe \"gpg\" ili \"gpg2\"")
("orange" "naran£asto")
("order" "poredak")
("ordinary symbol" "obi£an simbol")
("orientation" "orijentacija")
("origin" "ishodi²te")
("original welcome message" "izvorna poruka dobrodo²lice")
("ornament" "ukras")
("ornament border" "rub ukrasa")
("ornament color" "boja ukrasa")
("ornament extra color" "dodatna boja ukrasa")
("ornament shadow color" "boja sjene ukrasa")
("ornament shape" "oblik ukrasa")
("ornament sunny color" "sun£ana boja ukrasa")
("ornament title style" "stil naslova ukrasa")
("ornamented" "ukra²eno")
("other" "ostalo")
("other login" "druga prijava")
("other package" "drugi paketi")
("other pages" "ostale stranice")
("other projects" "drugi projekti")
("other style" "drugi stilovi")
("outer" "vanjsko")
("outer bottom" "vanjsko dno")
("outer left" "vanjsko lijevo")
("outer right" "vanjsko desno")
("outer top" "vanjski vrh")
("outline" "kontura")
("outlined" "konturirano")
("outlined emboss" "konturirani reljef")
("outlined engrave" "konturirano ugravirano")
("outlined roman" "konturirani latini£ni font")
("output" "izlaz")
("output options" "mogu¢nosti izlaza")
("oval" "ovalno")
("oval blur" "ovalno zamagljenje")
("over" "over")
("overbrace" "vitica iznad")
("overlap" "preklapanje")
("overlays" "prekrivanja")
("overlays compressed" "kompresirana prekrivanja")
("overlays greyed" "posivljena prekrivanja")
("overlays phantoms" "fantomska prekrivanja")
("overline" "nadcrtaj")
("overlined" "nadcrtano")
("overview of the scheme extension language" "pregled SCHEME jezika za pro²irivanje")
("pad" "ispuna")
("padding" "ispuna")
("padding above" "ispuna iznad")
("padding below" "ispuna ispod")
("padded" "s ispunom")
("padded center" "centrirano s ispunom")
("padded left aligned" "lijevo poravnanje s ispunom")
("padded right aligned" "desno poravnanje s ispunom")
("page" "stranica")
("page background" "pozadina stranice")
("page bottom margin" "donja margina stranice")
("page break" "prijelom stranice")
("page break after" "prijelom stranice iza")
("page break before" "prijelom stranice ispred")
("page breaking algorithm" "algoritam prijeloma stranica")
("page format" "oblikovanje stranice")
("page height" "visina stranice")
("page insertion" "uvr²tavanje stranice")
("page layout" "prikaz prijeloma")
("page number" "broj stranice")
("page number rendering" "renderiranje broja stranice")
("page numbering" "numeriranje stranice")
("page reference" "referenca na stranicu")
("page rendering" "renderiranje stranice")
("page right margin" "desna margina stranice")
("page setup" "postavke stranice")
("page top margin" "gornja margina stranice")
("page type" "vrsta stranice")
("page width" "²irina stranice")
("pages" "stranice")
("pale" "blijedo")
("pale blue" "blijedoplavo")
("palette" "paleta")
("paper" "papir")
("paper size" "veli£ina papira")
("paper type" "vrsta papira")
("papyrus" "papirus")
("paragraph" "odlomak")
("paragraph format" "oblikovanje odlomka")
("paragraph mode" "na£in odlomka")
("paragraph width" "²irina odlomka")
("paragraphs" "odlomci")
("parametric curve" "parametarski zadana krivulja")
("parametric surface" "parametarski zadana ploha")
("parchment" "pergament")
("parenthesis" "zagrade")
("parenthesized" "u zagradi")
("part" "dio")
("partfrac" "rastavljanje na parcijalne razlomke")
("particle" "£estica")
("passphrase encryption" "²ifriranje zaporke")
("passphrase wallet facilities are not currently available" "ureaji za lisnice sa zaporkom trenutno nisu dostupni")
("passphrases are expected to have at least: 8 characters" "zaporke moraju imati najmanje: 8 znakova")
("passphrases mismatch" "neusklaenost zaporki")
("password" "zaporka")
("past changes" "prija²nje promjene")
("paste" "zalijepi")
("paste from" "zalijepi iz")
("paste text" "zalijepi tekst")
("pastel" "pastelno")
("path" "staza")
("pattern" "uzorak")
("pattern selector" "izbornik uzorka")
("pause" "zastani")
("pdf" "PDF")
("pdf version number" "PDF ina£ica")
("pen" "pisaljka")
("pen angle" "kut pisaljke")
("pen height" "visina pisaljke")
("pen width" "²irina pisaljke")
("perform operations on cells" "obavi operacije na ¢elijama")
("perform operations on columns" "obavi operacije na stupcima")
("perform operations on entire table" "obavi operacije na £itavoj tablici")
("perform operations on rows" "obavi operacije na retcima")
("permanent" "trajno")
("permanent footer" "trajno podnoºje")
("permanent header" "trajno zaglavlje")
("permanently add to dictionary" "trajno dodaj u rje£nik")
("permanently insert into dictionary" "trajno umetni u rje£nik")
("permissions" "dozvole")
("person" "osoba")
("personal dictionary has been modified" "osobni rje£nik je promijenjen")
("phantasy" "fantazija")
("phantom" "fantom")
("phantoms" "fantomi")
("phdthesis" "disertacija")
("philosophy" "filozofija")
("phoenician" "feni£an")
("phonetic" "foneti£ko")
("physical constants" "fizikalne konstante")
("physical units" "fizikalne jedinice")
("physics and astronomy class" "razred fizike i astronomije")
("picture" "slika")
("pictures" "slike")
("pine" "jelovina")
("pink" "ruºi£asto")
("plain" "obi£no")
("plain block" "obi£ni blok")
("plain boxes" "obi£ne kutije")
("plain circles" "obi£ni krugovi")
("plain tabular" "obi£no tabeliranje")
("plain title" "obi£an naslov")
("planned changes" "planirane promjene")
("plans for the future" "planovi za budu¢nost")
("play" "pokreni")
("play animation" "pokreni animaciju")
("please" "molim")
("please install GnuPG software from https://www.gnupg.org" "molim instaliraj GnuPG softver s https://www.gnupg.org")
("please wait" "molim pri£ekaj")
("plot" "graf")
("plot curve" "nacrtaj krivulju")
("plot output" "izlazni graf")
("plotting" "prikazivanje grafova")
("plugin" "dodatak")
("plugins" "dodaci")
("plug-ins" "dodaci")
("plus" "plus")
("plural" "mnoºina")
("point" "to£ka")
("point border" "rub to£ke")
("point size" "veli£ina to£ke")
("point style" "stil to£ke")
("polar" "polarni")
("polish" "poljski")
("polygon" "poligon")
("polynomial arithmetic" "aritmetika polinoma")
("pop server settings" "postavke sko£nog posluºitelja")
("population standard deviation" "standardna devijacija populacije")
("porting TeXmacs to other platforms" "prijenos TeXmacsa na druge platforme")
("portrait" "portret")
("portuguese" "portugalski")
("position" "poloºaj")
("position float" "poloºaj plovka")
("position floating object" "poloºaj plutaju¢eg objekta")
("position of marginal note" "poloºaj bilje²ke na margini")
("position the table" "poloºaj tablice")
("poster" "plakat")
("poster formats" "formati postera")
("poster theme" "tema plakata")
("postfix" "postfiks")
("postscript" "PostScript")
("postscript image" "PostScript slika")
("power" "snaga")
("pre-alpha release" "pre-alfa izdanje")
("preamble" "preambula")
("preamble mode" "na£in preambule")
("preferences" "postavke")
("preferences for editing mathematical formulas" "postavke ureivanja matemati£kih formula")
("preferences for tag" "postavke okruºenja")
("prefix" "prefiks")
("prefix by section number" "broj odjeljka kao prefiks")
("presentation" "prezentacija")
("presentation mode" "prezentacijski na£in")
("presentation tag" "okruºenja prikaza")
("presentation tool" "alat za prezentacije")
("preserve" "zadrºi")
("preserve tags" "zadrºi okruºenja")
("pressure" "tlak")
("pretty" "renderirano")
("pretty tree output" "renderirano stablo izlaza")
("preview" "pretpregled")
("preview before printing" "pretpregled prije ispisa")
("preview command" "naredba za pretpregled")
("preview with ghostview" "pretpregled s GhostViewom")
("previous" "prethodno")
("previous difference" "prethodno razlikovanje")
("previous error" "prethodna gre²ka")
("previous field" "prethodno polje")
("previous occurrence" "prethodno pojavljivanje")
("previous screen" "prethodni zaslon")
("previous similar" "prethodno sli£no")
("primary" "primarno")
("prime" "prim")
("primitive or macro" "temeljni konstrukt ili makro")
("print" "ispis")
("print all" "ispi²i sve")
("print all to file" "ispi²i sve u datoteku")
("print buffer" "ispis spremnika")
("print buffer to file" "ispis spremnika u datoteku")
("print page selection" "ispis ozna£enih stranica")
("print page selection to file" "ispis ozna£enih stranica u datoteku")
("print to postscript file" "ispis u PostScript datoteku")
("printer" "pisa£")
("printer dpi" "DPI za pisa£")
("printer setup" "postavljanje pisa£a")
("printing command" "naredba za ispis")
("probability and statistics" "vjerojatnost i statistika")
("problem" "problem")
("proceed" "nastavi")
("produce Pdf using native export filter" "upotrijebi vlastiti filter za izvoz u PDF")
("produce Postscript using native export filter" "upotrijebi vlastiti filter za izvoz u Postscript")
("professional" "profesionalno")
("prog" "prog")
("prog font" "prog-font")
("prog font family" "familija prog-font")
("prog font series" "vrsta prog-fonta")
("prog font shape" "oblik prog-fonta")
("program" "program")
("program bracket matching" "sparivanje zagrada u programskom kodu")
("program bracket selections" "ozna£avanje zagrada u programskom kodu")
("program commands" "naredbe za program")
("program font" "font programskog koda")
("program interface for buffer management" "programsko su£elje za upravljanje spremnicima")
("program mode" "na£in programa")
("programming" "programiranje")
("programming routines for editing documents" "programske rutine za ureivanje dokumenata")
("progressive" "progresivno")
("project" "projekt")
("projector" "projektor")
("projects" "projekti")
("prologue" "prolog")
("prominent" "istaknuto")
("prompt on scripts" "upit za skripte")
("prompts and default input" "upiti i zadani unos")
("proof" "dokaz")
("properties" "svojstva")
("proportional" "srazmjerno")
("proportional typewriter" "srazmjerna slova pisa¢eg stroja")
("proposition" "propozicija")
("provoke" "izazovi")
("provoke C++ error" "izazovi C++ pogre²ku")
("provoke menu error" "izazovi pogre²ku izbornika")
("provoke scheme error" "izazovi SCHEME pogre²ku")
("pt" "to£aka")
("pseudo code" "pseudokod")
("public key encryption" "²ifriranje javnog klju£a")
("public keys" "javni klju£evi")
("pulse" "puls")
("python Source Code" "izvorni Python kod")
("qt GUI only, sorry. Use \"Export selection\"" "samo Qt GUI, naºalost. Upotrijebi \"Izvoz izbora\"")
("qt-widgets" "qt-widgeti")
("quadratic forms" "kvadratne forme")
("quantifier" "kvantifikator")
("quantiles" "kvantili")
("quartiles" "kvartili")
("quasi" "kvazi")
("query replace" "potvrda zamjene")
("question" "pitanje")
("questions only" "samo pitanja")
("questions with answers" "pitanja s odgovorima")
("quick evaluation of formulas" "brza evaluacija formula")
("quit" "zatvori")
("quotation" "navod")
("quote" "navedi")
("quote env" "okruºenje za navod")
("quote left indentation" "lijevo uvla£enje navoda")
("quote right indentation" "desno uvla£enje navoda")
("radiation" "zra£enje")
("radius" "radijus")
("radius x" "radijus x")
("radius y" "radijus y")
("range" "raspon")
("rank" "rang")
("raw" "sirovo")
("(Re)Build autocompletion index" "(Ponovno) sastavi indeks dovr²avanja teksta")
("real" "realni")
("real numbers" "realni brojevi")
("really close it" "zaista ga zatvori")
("really delete user identity" "zaista izbrisati identitet korisnika")
("really huge" "zaista golemo")
("really quit" "zaista zatvori")
("really tiny" "zaista sitno")
("rebuild translations file" "obnovi datoteku prijevoda")
("recent" "nedavno")
("recent documents" "nedavni dokumenti")
("recolor" "ponovno oboji")
("recover autosave file" "povrati automatski pohranjenu datoteku")
("rectangle" "pravokutnik")
("rectangular" "pravokutno")
("rectangular blur" "pravokutno zamagljenje")
("red" "crveno")
("reddish" "crvenkasto")
("redo" "ponovi")
("redo undone changes" "ponovi poni²tene promjene")
("reduce" "smanji")
("reduce bottom by" "smanji dno za")
("reduce bottom margin by" "smanji donju marginu za")
("reduce by" "smanji za")
("reduce left margin by" "smanji lijevu marginu za")
("reduce margins" "smanji margine")
("reduce right margin by" "smanji desnu marginu za")
("reduce top by" "smanji vrh za")
("reduce top margin by" "smanji gornju marginu za")
("reduce trigonometric functions" "reduciranje trigonometrijskih izraza")
("reduced margins" "smanjene margine")
("reduction even page margin" "smanjenje margine parne stranice")
("reduction odd page margin" "smanjenje margine neparne stranice")
("reduction page bottom margin" "smanjenje donje margine stranice")
("reduction page right margin" "smanjenje desne margine stranice")
("reduction page top margin" "smanjenje gornje margine stranice")
("reference" "referenca")
("reference guide" "referentni vodi£")
("reference guide for the TeXmacs primitives" "referentni vodi£ kroz temelje TeXmacsa")
("reference guide for the standard TeXmacs styles" "referentni vodi£ za zadane TeXmacs stilove")
("reference to note" "referenca na bilje²ku")
("references" "reference")
("register" "registriraj")
("regular" "regularno")
("relate" "dovedi u vezu")
("relation" "odnos")
("release" "izdanje")
("release left button: finish editing" "pu²tanje lijeve tipke: dovr²etak ureivanja")
("reload" "ponovno u£itaj")
("remark" "napomena")
("remote" "udaljeno")
("remote connections" "daljinske veze")
("remote control" "daljinsko upravljanje")
("remote controllers with keyboard simulation" "daljinski upravlja£i sa simulacijom tipkovnice")
("remote directory" "udaljeni direktorij")
("remote login" "daljinska prijava")
("remote servers" "udaljeni posluºitelji")
("remote plug-ins" "daljinski priklju£ci")
("remote tool" "daljinski alat")
("remove" "ukloni")
("remove all output fields" "ukloni sva polja za unos")
("remove argument after" "ukloni argument iza")
("remove argument before" "ukloni argument ispred")
("remove banner" "ukloni uvodni natpis")
("remove downwards" "uklanjaj prema dolje")
("remove entry" "ukloni upis")
("remove entries" "ukloni upise")
("remove field above" "ukloni polje iznad")
("remove field below" "ukloni polje ispod")
("remove fields" "ukloni polja")
("remove folded" "ukloni preklopljeno")
("remove input field" "ukloni polje za unos")
("remove input field above" "ukloni gornje polje za unos")
("remove last field" "ukloni posljednje polje")
("remove leftwards" "uklanjaj na lijevo")
("remove link" "ukloni poveznicu")
("remove next field" "ukloni sljede¢e polje")
("remove number" "ukloni broj")
("remove package" "ukloni paket")
("remove previous field" "ukloni prethodno polje")
("remove remote ssh connection" "ukloni daljinsku SSH vezu")
("remove rightwards" "uklanjaj na desno")
("remove selected database entries" "ukloni odabrane upise u bazi podataka")
("remove selected entries" "ukloni odabrane upise")
("remove superfluous invisible operators" "ukloni suvi²ne nevidljive operatore")
("remove tag" "ukloni okruºenje")
("remove this branch" "ukloni ovaj ogranak")
("remove this switch" "ukloni ovu skretnicu")
("remove unfolded" "ukloni razvijeno")
("remove upwards" "uklanjaj prema gore")
("removed entries from database" "uklonjeni upisi iz baze podataka")
("removed entry from database" "uklonjen upis iz baze podataka")
("rename" "promijeni naziv")
("rename section" "preimenovanje odjeljka")
("render code" "renderiranje programskog koda")
("render key" "renderiranje tipke")
("rendering" "renderiranje")
("rendering options for tag" "mogu¢nosti renderiranja okruºenja")
("renumber this page" "ponovno numeriranje ove stranice")
("repeat" "ponavljanje")
("repeat object" "ponavljanje objekta")
("replace" "zamijeni")
("replace all further occurrences" "zamijeni sva naredna pojavljivanja")
("replace by" "zamijeni sa")
("replace one occurrence" "zamijeni jednom")
("replace TeXmacs styles with no LaTeX equivalents" "nemoj zamijeniti TeXmacs stilove ekvivalentima u LaTeXu")
("replace toolbar" "alatna traka za zamjenjivanje")
("replace unrecognized styles" "zamijeni neprepoznate stilove")
("replaced" "zamijenjeno")
("replaced one occurrence" "jedno pojavljivanje zamijenjeno")
("research papers" "istraºiva£ki radovi")
("reset" "postavi u po£etno stanje")
("reset error counters" "resetiranje broja£a pogre²aka")
("resize" "promijeni veli£inu")
("resize object" "promijeni veli£inu objekta")
("resize objects" "promijeni veli£ine objekata")
("resized" "promijenjene veli£ine")
("restart TeXmacs in order to let changes take effect" "ponovno pokreni TeXmacs kako bi promjene do²le do izraºaja")
("restart in order to let the new look and feel take effect" "ponovno pokreni kako bi novi izgled do²ao do izraºaja")
("retime" "retime")
("rewriting" "pretvorba zapisa")
("search and replace" "traºi i zamijeni")
("search preferences" "postavke pretraºivanja")
("search results for" "rezultati pretrage pojma")
("search words" "traºi rije£i")
("search words in recent documents" "traºi rije£i u nedavnim dokumentima")
("several equations" "nekoliko jednadºbi")
("skew" "iskosi")
("snap" "hvatanje")
("snap distance" "udaljenost hvatanja")
("snap to curves" "hvatanje za krivulje")
("snap to grid" "hvatanje za mreºu")
("snap to grid curve" "hvatanje za krivulju mreºe")
("snap to intersections of curves" "hvatanje za sjeci²ta krivulja")
("snap to pages" "prilagodi stranicama")
("snap to text borders" "hvatanje za rubove teksta")
("snap to text corners" "hvatanje za uglove teksta")
("star" "zvijezda")
("statement" "izjava")
("statistics" "statistika")
("storage" "pohrana")
("store tracking information in LaTeX files" "pohrani podatke o pra¢enju u LaTeX datoteke")
("strict Ascii" "strogi ASCII")
("strike through" "precrtaj")
("string" "niz")
("retain" "zadrºi")
("retina settings" "postavke mreºnice")
("retrieve email" "dohva¢anje e-po²te")
("retrieve remote live document" "dohva¢anje udaljenog dokumenta uºivo")
("retrieved contents" "dohva¢eni sadrºaji")
("return" "return")
("reverse" "obrnuto")
("reverse ordering" "obrnuti poredak")
("revert" "povrati")
("revert buffer" "povrati spremnik")
("ridged" "grebenasto")
("ridged paper" "grebenasti papir")
("right" "desno")
("right arrow" "desna strelica")
("right baseline" "desna osnovica")
("right border" "desni rub")
("right cell border" "desni rub ¢elije")
("right cell padding" "desna ispuna ¢elije")
("right down" "desno dolje")
("right margin" "desna margina")
("right on even pages" "desno na parnim stranicama")
("right padding" "desna ispuna")
("right aligned" "poravnato nadesno")
("right subscript" "desni indeks")
("right superscript" "desni eksponent")
("right surrounding" "desno naokolo")
("right table border" "desni rub tablice")
("right table padding" "desna ispuna tablice")
("right up" "desno gore")
("rightwards" "nadesno")
("rigid" "kruto")
("rigid box" "kruta kutija")
("rigid horizontal" "kruto vodoravno")
("rigid space" "kruti razmak")
("ring binder notebook style" "stil spiralnog uveza")
("romanian" "rumunjski")
("root" "korijen")
("rotate" "rotiraj")
("rotate backward" "rotiraj unatrag")
("rotate forward" "rotiraj unaprijed")
("rotate objects" "rotiraj objekte")
("rough" "grubo")
("rough paper" "grubi papir")
("round" "okruglo")
("round overbrace" "zaobljena gornja vitica")
("round underbrace" "zaobljena donja vitica")
("rounded" "zaobljeno")
("row" "redak")
("row above" "redak iznad")
("row below" "redak ispod")
("row contains glued items" "redak sadrºi slijepljene elemente")
("rows" "retci")
("run" "pokreni")
("run current file" "pokretanje trenutne datoteke")
("runic" "runski")
("running author" "teku¢i autor")
("running title" "teku¢i naslov")
("russian" "ruski")
("same names" "isti nazivi")
("same screen margins as on paper" "jednake margine na papiru i zaslonu")
("sample" "bez serifa")
("sample text" "primjerak teksta")
("sans serif" "bez serifa")
("sans Serif" "bez serifa")
("save" "pohrani")
("save TeXmacs file" "pohrani TeXmacs datoteku")
("save TeXmacs style file" "pohrani TeXmacs stilsku datoteku")
("save as" "pohrani kao")
("save as LaTeX" "pohrani kao LaTeX")
("save as TeX" "pohrani kao TeX")
("save auxiliary data" "pohrani pomo¢ne podatke")
("save buffer" "pohrani spremnik")
("save buffer as" "pohrani spremnik kao")
("save entries" "pohrani upise")
("save entry" "pohrani upis")
("save file" "pohrani datoteku")
("save html file" "pohrani HTML datoteku")
("save image" "pohrani sliku")
("save image as" "pohrani sliku kao")
("save latex file" "pohrani latex datoteku")
("save position" "pohrani poloºaj")
("save remote file" "pohrani udaljenu datoteku")
("save tex file" "pohrani tex datoteku")
("save this buffer" "pohrani ovaj spremnik")
("save verbatim file" "pohrani doslovnu datoteku")
("saved" "pohranjeno")
("saved modifications in database" "pohranjene promjene u bazi podataka")
("scala Source Code" "izvorni Scala kod")
("scheme" "SCHEME")
("scheme command" "SCHEME naredba")
("scheme developers guide" "vodi£ za SCHEME razvijatelje")
("scheme extensions" "SCHEME pro²irenja")
("scheme interface for the graphical mode" "SCHEME su£elje za grafi£ki na£in")
("scheme source" "izvorni Scheme kod")
("scheme Source Code" "izvorni Scheme kod")
("scifi" "znan-fan")
("screen" "zaslon")
("screen layout" "prijelom i respored na zaslonu")
("screen margins" "margine na zaslonu")
("screen rendering" "renderiranje na zaslonu")
("screens" "zasloni")
("screenshot" "snimka zaslona")
("script" "natpis")
("script above" "natpisivanje")
("script below" "potpisivanje")
("script input" "unos skripte")
("script output" "izlaz skripte")
("script script size" "veli£ina indeksa indeksa")
("script size" "veli£ina indeksa")
("scripting language" "jezik skriptiranja")
("scripts" "skripte")
("scripts not accepted" "skripte nisu prihva¢ene")
("search" "pretraºivanje")
("search and replace" "traºi i zamijeni")
("search toolbar" "alatna traka za pretraºivanje")
("search words in my documents" "pretraºivanje rije£i u dokumentu")
("search words in the documentation" "pretraºivanje rije£i u dokumentaciji")
("search words in the source code" "pretraºivanje rije£i u izvornom kodu")
("searching" "pretraºivanje u tijeku")
("second" "drugi")
("secondary" "sekundarno")
("secret keys" "tajni klju£evi")
("section" "odjeljak")
("section display numbers" "prikazivanje broja odjeljka")
("section slide" "slajd s nazivom odjeljka")
("sections" "odjeljci")
("security" "sigurnost")
("see" "vidi")
("see documentation" "vidi dokumentaciju")
("select a document style" "odaberi stil dokumenta")
("select a foreground color" "odaberi boju prednjeg plana")
("select a language" "odaberi jezik")
("select color" "odaberi boju")
("select pen" "odaberi pisaljku")
("select the action to be undertaken for each conflict" "odaberi radnju koju treba poduzeti prilikom svakog konflikta")
("select view mode" "odaberi na£in prikazivanja")
("selected" "odabrani")
("selected region" "odabrana regija")
("selection" "selekcija")
("selections" "selekcije")
("semantic correctness" "semanti£ka to£nost")
("semantic editing" "semanti£ko ureivanje")
("semantic selections" "semanti£ke selekcije")
("semantics" "semantika")
("seminar" "seminar")
("sending commands to TeXmacs" "upu¢ivanje naredbi TeXmacsu")
("senior" "stariji")
("separation between lines" "razmak meu retcima")
("separation between paragraphs" "razmak meu odlomcima")
("separator" "razdjelnik")
("september" "rujan")
("serb" "srpsko")
("series" "serija")
("series|right" "serija|desno")
("serif" "serif")
("server" "posluºitelj")
("session" "sesija")
("session commands" "naredbe sesije")
("session name" "naziv sesije")
("session type" "vrsta sesije")
("sessions" "sesije")
("set" "postavi")
("set background color of cell" "postavi boju pozadine ¢elije")
("set cell mode" "postavi na£in ¢elije")
("set default" "postavi zadano")
("set difference" "skupovna razlika")
("set extension center" "postavi sredi²te pro²irenja")
("set height" "postavi visinu")
("set height of cell" "postavi visinu ¢elije")
("set intersection" "presjek skupova")
("set margins" "postavi margine")
("set n" "postavi n")
("set number of columns" "postavi broj stupaca")
("set number of rows" "postavi broj redaka")
("set or get environment variables" "postavi ili dohvati varijable okruºenja")
("set paragraph margins" "postavi margine odlomka")
("set paragraph mode" "postavi na£in odlomka")
("set printer dpi" "postavi DPI pisa£a")
("set printing command" "postavi naredbu za ispis")
("set properties" "postavi svojstva")
("set span" "postavi raspon")
("set special cell properties" "postavi posebne zna£ajke ¢elije")
("set special table properties" "postavi posebne zna£ajke tablice")
("set text width" "postavi ²irinu teksta")
("set union" "unija skupova")
("set user information" "postavi podatke o korisniku")
("set width" "postavi ²irinu")
("set width of cell" "postavi ²irinu ¢elije")
("settings" "postavke")
("setup printer" "postavi pisa£")
("seventh" "sedmo")
("shape" "oblik")
("sharpness" "o²trina")
("shadow" "sjena")
("shadowed" "zasjenjeno")
("shadowed raise" "zasjenjeno podizanje")
("shift" "pomak")
("shift-down" "pomak prema dolje")
("shift-right" "pomak na desno")
("short" "kratko")
("shortcut" "pre£ica")
("show" "prikaºi")
("show all parts" "prikaºi sve dijelove")
("show current focus" "prikaºi trenutni fokus")
("show full context" "prikaºi cijeli kontekst")
("show grid" "prikaºi mreºu")
("show header and footer" "prikaºi zaglavlje i podnoºje")
("show hidden" "prikaºi ono ²to je skriveno")
("show key presses" "prikazuj koje su tipke pritisnute")
("show memory usage" "prikazuj raspolaganje memorijom")
("show on screen" "prikaºi na zaslonu")
("show one part" "prikaºi jedan dio")
("show panorama" "panoramski prikaz")
("show preamble" "prikaºi preambulu")
("show several parts" "prikaºi nekoliko dijelova")
("show subunits" "prikaºi podjedinice")
("show table cells" "prikaºi ¢elije tablice")
("show timings" "prikazuj mjerenje vremena")
("shown" "prikazano")
("shrinking factor" "faktor smanjivanja")
("side tools" "alati sa strane")
("signal processing" "obrada signala")
("signature" "potpis")
("simple" "jednostavno")
("simplify" "pojednostavni")
("simplification" "pojednostavljivanje")
("simplified evaluation of formulas" "pojednostavljena evaluacija formula")
("simplified menus" "pojednostavljeni izbornici")
("sine" "sinus")
("sixth" "²esto")
("size" "veli£ina")
("size limits" "granice veli£ine")
("size tag" "okruºenja veli£ine")
("skin" "koºa")
("skip all" "presko£i sve")
("slant" "nako²enost")
("slanted" "nako²eno")
("slashed fraction" "razlomak s kosom crtom")
("slide" "slajd")
("slides" "slajdovi")
("slideshow" "prezentacija")
("sloppy" "neuredno")
("slovene" "slovenski")
("slow" "sporo")
("slow decrease" "sporo smanjenje")
("slow increase" "sporo pove¢anje")
("small" "maleno")
("small capitals" "mali verzal")
("small Capitals" "mali verzal")
("small caps" "mali verzal")
("small environment box" "mala kutija okruºenja")
("small figure" "mala slika")
("small focus" "mali fokus")
("small inline" "maleno unutarlinijsko")
("small inline fraction" "maleni razlomak unutar retka")
("small skip" "mali preskok")
("small table" "mala tablica")
("smash" "razbij")
("smash bottom" "razbij dno")
("smash top" "razbij vrh")
("smooth" "glatko")
("smooth end" "gladak zavr²etak")
("smooth extremities" "glatki ekstremiteti")
("smooth start" "gladak po£etak")
("solution" "rje²enje")
("solution to exercise" "rje²enje zadatka")
("solve" "rije²i")
("solve in" "rije²i u")
("solving" "rje²avanje")
("solving equations" "rje²avanje jednadºbi")
("sound" "zvuk")
("source" "izvornik")
("source code" "izvorni kod")
("source Code" "izvorni kod")
("source directory" "izvorni direktorij")
("source macros tool" "alat za izvorne makroe")
("source tags" "okruºenja izvora")
("south" "jug")
("south east" "jugoistok")
("space" "razmak")
("space bar in text mode" "razmaknica u tekstualnom na£inu")
("space bar in math mode" "razmaknica u matemati£kom na£inu")
("space between lines" "razmak meu retcima")
("space between paragraphs" "razmak meu odlomcima")
("space stretchability" "rastezljivost razmaka")
("spacing" "razmicanje")
("span" "raspon")
("span over all columns" "raspon preko svih stupaca")
("spanish" "²panjolski")
("special" "posebno")
("special cell properties" "posebne zna£ajke ¢elije")
("special cell properties and actions" "posebne radnje i zna£ajke ¢elije")
("special functions" "specijalne funkcije")
("special properties" "posebne zna£ajke")
("special table properties" "posebne zna£ajke tablice")
("specific" "specifi£no")
("specific baseline" "specifi£na osnovica")
("specified" "odreeno")
("specify color alternation" "navedi izmjenu boja")
("specify how to traverse the manual" "navedi kako prije¢i priru£nik")
("specify semantics of a symbol or formula" "navedi semantiku simbola ili formule")
("specify the size of the table" "navedi veli£inu tablice")
("specify user identity" "navedi identitet korisnika")
("spell" "provjeri pravopis")
("spell check" "provjera pravopisa")
("spell checking complete" "provjera pravopisa je zavr²ena")
("spelling error" "pravopisna pogre²ka")
("spelling errors have been corrected" "pravopisne pogre²ke su ispravljene")
("spline" "splajn")
("split" "razdvoji")
("split program" "razdvoji program")
("split session" "razdvoji sesiju")
("square" "kvadrat")
("square overbrace" "uglata gornja vitica")
("square underbrace" "uglata donja vitica")
("square root" "kvadratni korijen")
("stack" "stog")
("standard" "standardno")
("standard deviation" "standardna devijacija")
("standard environment variables" "standardne varijable okruºenja")
("standard formats" "standardni formati")
("standard fraction" "standardni razlomak")
("standard output" "standardni izlaz")
("standard TeXmacs styles" "standardni TeXmacs stilovi")
("start" "po£etak")
("start a new chapter" "zapo£ni novo poglavlje")
("start a new section" "zapo£ni novi odjeljak")
("start an interactive session" "pokreni interaktivnu sesiju")
("start remote session" "pokreni udaljenu sesiju")
("start server" "pokretanje posluºitelja")
("statement" "izjava")
("status bar" "statusna traka")
("stop server" "zaustavi server")
("storage" "pohrana")
("store tracking information in LaTeX files" "pohrani podatke za pra¢enje u LaTeX datoteke")
("strength" "ja£ina")
("stretch" "rastezljivost")
("stretch factor" "faktor rastezljivosti")
("stretchable" "rastezljivo")
("stretchable horizontal" "rastezljivo po ²irini")
("stretchable vertical" "rastezljivo po visini")
("stretched" "rastegnuto")
("stroke" "potez")
("strokes" "potezi")
("strong" "snaºno")
("structural" "strukturalan")
("structured insert above" "strukturirano umetanje iznad")
("structured insert at the left" "strukturirano umetanje slijeva")
("structured insert at the right" "strukturirano umetanje zdesna")
("structured insert below" "strukturirano umetanje ispod")
("structured remove downwards" "strukturirano uklanjanje prema dolje")
("structured remove leftwards" "strukturirano uklanjanje zdesna")
("structured remove rightwards" "strukturirano uklanjanje slijeva")
("structured remove upwards" "strukturirano uklanjanje prema gore")
("structured variant" "strukturirana varijanta")
("style" "stil")
("style options" "mogu¢nosti stila")
("style parameters" "parametri stila")
("styles" "stilovi")
("stylesheet language" "jezik stila")
("sub" "pod")
("subject" "predmet")
("submenu" "podizbornik")
("subparagraph" "pododlomak")
("subscript" "indeks")
("subscript below" "indeks ispod")
("subsection" "pododjeljak")
("subsub" "podpod")
("subsubmenu" "podpodizbornik")
("subsubsection" "podpododjeljak")
("subsubsubmenu" "podpodpodizbornik")
("subsubsubsubmenu" "podpodpodpodizbornik")
("subtable" "podtablica")
("subtitle" "podnaslov")
("subtraction" "oduzimanje")
("summarized" "saºeto")
("summary" "saºetak")
("summary of the principal TeXmacs tags" "saºetak glavnih okruºenja u TeXmacsu")
("superpose" "superponiraj")
("superposed" "jedan iznad drugog")
("superscript" "eksponent")
("superscript above" "eksponent iznad")
("supported plug-ins" "podrºani priklju£ci")
("surface" "ploha")
("surveys" "ankete")
("swedish" "²vedski")
("swell" "zadebljaj")
("swell bottom" "zadebljaj pri dnu")
("swell top" "zadebljaj pri vrhu")
("swiss" "²vicarski")
("switch" "prebaci")
("switch to first" "prebaci na prvi")
("switch to formula style" "prebaci u stil formula")
("switch to last" "prebaci na posljednji")
("switch to next" "prebaci na sljede¢i")
("switch to previous" "prebaci na prethodni")
("switching and folding" "prebacivanje i preklapanje")
("synchronize" "sinkroniziraj")
("synchronize bibliographic references" "sinkroniziranje bibliografskih referenci")
("synchronize with remote server" "sinkronizacija s udaljenim posluºiteljem")
("symbol" "simbol")
("symbol browser" "preglednik simbola")
("symbol properties not found" "svojstva simbola nisu pronaena")
("symbols" "simboli")
("synopsis" "sinopsis")
("system command" "sistemska naredba")
("system environment variables" "sistemske varijable okruºenja")
("tab" "tabulator")
("tab-completion" "dovr²avanje rije£i")
("tabbed" "tabelirano")
("table" "tablica")
("table breaking" "prelamanje tablice")
("table command" "naredba za tablicu")
("table height" "visina tablice")
("table of contents" "sadrºaj")
("table properties" "svojstva tablice")
("table width" "²irina tablice")
("tables" "tablice")
("tabular" "tabelarni")
("tabular material" "tabelarni materijal")
("tags with special rendering" "okruºenja s posebnim renderiranjem")
("taiwanese" "tajvanski")
("tangent" "tangens")
("target" "odredi²te")
("techreport" "tehni£ki izvje²taj")
("temperature" "temperatura")
("teXmacs as an interface" "TeXmacs kao su£elje")
("teXmacs box style" "teXmacs stil kutija")
("teXmacs buffer expected" "o£ekuje se spremnik TeXmacsa")
("teXmacs buffer on disk expected" "o£ekuje se spremnik TeXmacsa na disku")
("teXmacs database preferences" "postavke TeXmacsa za baze podataka")
("teXmacs DTD" "teXmacs DTD")
("teXmacs extensions to scheme and utilities" "pro²irenja TeXmacsa u SCHEME jeziku i korisni programi")
("teXmacs fonts" "fontovi TeXmacsa")
("teXmacs macro" "makro TeXmacsa")
("teXmacs manual" "teXmacs priru£nik")
("teXmacs notice" "obavijest TeXmacsa")
("teXmacs package" "teXmacs paket")
("teXmacs plugins" "dodaci TeXmacsu")
("teXmacs primitives" "korijeni TeXmacsa")
("teXmacs style" "teXmacs stil")
("teXmacs style files" "datoteke TeXmacs stilova")
("teXmacs website" "web-stranica TeXmacsa")
("ternary" "trostruko")
("tertiary" "tercijarno")
("test" "test")
("test routine" "testiraj rutinu")
("testing tree-view" "testiranje prikaza stabla")
("tex" "tex")
("text" "tekst")
("text at" "tekst na")
("text borders" "rubovi teksta")
("text corners" "uglovi teksta")
("text font" "font teksta")
("text for note" "tekst bilje²ke")
("text height correction" "ispravak visine teksta")
("text width" "²irina teksta")
("texts" "tekstovi")
("textual" "tekstualno")
("textual operator" "tekstualni operator")
("textual spreadsheet" "tekstualna prora£unska tablica")
("textual table" "tekstualna tablica")
("th century BC" "-to stolje¢e prije Krista")
("th root" "-ti korijen")
("theme" "tema")
("threshold" "prag")
("through the menus" "preko izbornika")
("through popup windows" "preko sko£nih prozora")
("thai" "tajlandski")
("the document has not been saved" "dokument nije pohranjen")
("the TeXmacs authors" "autori TeXmacsa")
("the TeXmacs format" "TeXmacs format")
("the TeXmacs plug-in system" "TeXmacs sustav priklju£aka")
("the application did not send its usual startup banner" "aplikacija nije poslala svoj uobu£ajeni natpis pri pokretanju")
("the application does not reply" "aplikacija ne odgovara")
("the application is already running" "aplikacija je ve¢ pokrenuta")
("the boxes produced by the typesetter" "kutije koje je na£inio slagar")
("the buffer has not been saved" "spremnik nije pohranjen")
("the graphical user interface" "grafi£ko korisni£ko su£elje")
("the leaves of TeXmacs trees" "listovi TeXmacs stabla")
("the mycas example" "mycas primjer")
("the primitive TeXmacs constructs" "primitivni konstrukti TeXmacsa")
("the standard TeXmacs styles" "uobi£ajeni stilovi TeXmacsa")
("theme parameters" "parametri teme")
("theorem" "teorem")
("there are unsaved documents" "neki dokumenti nisu pohranjeni")
("there are unsaved files" "neke datoteke nisu pohranjene")
("these collected public keys will be definitely lost" "ovi prikupljeni javni klju£evi bit ¢e definitivno izgubljeni")
("these public keys will be definitely lost" "ovi javni klju£evi bit ¢e definitivno izgubljeni")
("these secret keys will be definitely lost" "ovi ¢e tajni klju£evi biti definitivno izgubljeni")
("thicken" "podebljaj")
("thickness" "debljina")
("thin" "tanko")
("third" "tre¢e")
("this" "ovo")
("this buffer has not been saved" "ovaj spremnik nije pohranjen")
("this column" "ovaj stupac")
("this document has been written using" "ovaj je dokument napisan koriste¢i")
("this line" "ovaj redak")
("this page" "ova stranica")
("this page footer" "podnoºje ove stranice")
("this page header" "zaglavlje ove stranice")
("this page number" "broj ove stranice")
("this row" "ovaj redak")
("this style specifies page margins in the TeX way" "ovaj stil odreuje margine stranice na na£in TeX-a")
("three columns" "tri stupca")
("three dots" "tri to£kice")
("three times" "triput")
("thumbnails" "sli£ice")
("tilda" "tilda")
("tilde" "tilda")
("time" "vrijeme")
("time evolution" "razvoj vremena")
("times" "times")
("timings" "mjerenje vremena")
("tiny" "sitno")
("title" "naslov")
("title presentation options" "mogu¢nosti prikaza naslova")
("title slide" "slajd s naslovom")
("title style" "stil naslova")
("title suffix" "sufiks naslova")
("titled block" "blok s naslovom")
("to the left" "na lijevo")
("to the right" "na desno")
("toc prefix" "prefiks sadrºaja")
("today" "dana²nji datum")
("toggle cell wrapping mode" "omatanje ¢elije")
("toggle here" "prebaci ovdje")
("toggle off" "isklju£ivanje")
("toggle on" "uklju£ivanje")
("tolerant" "tolerantno")
("tools" "alati")
("top" "vrh")
("top baseline" "gornja osnovica")
("top border" "gornji rub")
("top cell border" "gornji rub ¢elije")
("top cell padding" "gornja ispuna ¢elije")
("top center" "na vrhu po sredini")
("top left" "na vrhu lijevo")
("top level" "gornji nivo")
("top margin" "gornja margina")
("top padding" "gornja ispuna")
("top right" "na vrhu desno")
("top table border" "gornji rub tablice")
("top table padding" "gornja ispuna tablice")
("topless title" "naslov pri vrhu")
("transform" "transformacija")
("transform cell into subtable" "Pretvori ¢eliju u podtablicu")
("transformations" "transformacije")
("translate" "prevedi")
("translations" "prijevodi")
("translations loaded" "prijevodi su u£itani")
("transpose" "transponiraj")
("traversal" "prelaºenje")
("traverse" "prijei")
("tree" "stablo")
("triangle" "trokut")
("triangular list items" "trokutaste stavke popisa")
("triangularize" "trianguliraj")
("trigonometric" "trigonometrijski")
("trigonometric functions" "trigonometrijske funkcije")
("trigonometry" "trigonometrija")
("try to import formulas using LaTeX annotations" "poku²aj uvesti formule koriste¢i LaTeX bilje²ke")
("tuple" "n-torka")
("turkish" "turski")
("turn off" "isklju£i")
("turn on" "uklju£i")
("tutorial" "tutorijal")
("tutorials" "tutorijali")
("twice" "dvaput")
("two columns" "dva stupca")
("two dots" "dvije to£kice")
("type" "vrsta")
("type a LaTeX command followed by return" "unesi LaTeX naredbu pa pritisni Enter")
("type body" "unesi tijelo teksta")
("type denominator" "unesi nazivnik")
("type numerator" "unesi brojnik")
("type script" "unesi skriptu")
("typesetted boxes" "sloºene kutije")
("typewriter" "pisa¢i stroj")
("typewriter small caps" "smanjena velika slova pisa¢eg stroja")
("typing a simple text" "unos jednostavnog teksta")
("typing simple texts" "unos jednostavnih dokumenata")
("ugaritic" "ugaritic")
("ukrainian" "ukrajinski")
("ultra compact" "ultra kompaktno")
("unchanged" "nepromijenjeno")
("underbrace" "donja vitica")
("underline" "podcrtaj")
("underlined" "podcrtano")
("undo" "poni²ti")
("undo last changes" "poni²ti posljednje promjene")
("unevaluated argument" "neevaluirani argument")
("unevaluated value" "neevaluirana veli£ina")
("unextended" "neproduljeno")
("unfold" "razvij")
("unfold all" "razvij sve")
("unfold all fields" "razvij sva polja")
("unfolded" "razvijeno")
("ungroup" "razgrupiraj")
("unit" "jedinica")
("unit length" "jedinica duljine")
("unknown secret key fingerprint" "nepoznati otisak tajnog klju£a")
("unpublished" "neobjavljeno")
("unregistered file" "neregistrirana datoteka")
("unroll" "razmotaj")
("unroll compressed" "razmotaj kompresirano")
("unroll greyed" "razmotaj posivljeno")
("unroll phantoms" "razmotaj fantome")
("unsecure script refused" "odbijena nesigurna skripta")
("unsupported link mode" "nepodrºani na£in veze")
("until" "do")
("untitled block" "blok bez naslova")
("up" "gore")
("up to date" "aºurirano")
("update" "aºuriraj")
("update from web" "mreºno aºuriranje")
("update image links" "aºuriraj poveznice slika")
("update remote ssh connection" "aºuriraj daljinsku SSH vezu")
("update this buffer" "aºuriraj ovaj spremnik")
("update web site" "aºuriraj web-stranicu")
("upgrade" "nadogradi")
("upper border" "gornji rub")
("upright" "uspravno")
("upwards" "prema gore")
("use margin kerning (protrusion)" "koristi kerning margina (izbo£enje)")
("use MathML" "koristi MathML")
("use TeXmacs" "koristi TeXmacs")
("use a black color" "koristi crnu boju")
("use a blue color" "koristi plavu boju")
("use a bold font" "koristi podebljana slova")
("use a brown color" "koristi smeu boju")
("use a calligraphic font" "koristi kaligrafska slova")
("use a green color" "koristi zelenu boju")
("use a grey color" "koristi sivu boju")
("use a magenta color" "koristi purpurnocrvenu boju")
("use a orange color" "koristi naran£astu boju")
("use a pink color" "koristi ruºi£astu boju")
("use a red color" "koristi crvenu boju")
("use a sans serif font" "koristi font bez serifa")
("use a typewriter font" "koristi font pisa¢eg stroja")
("use a white color" "koristi bijelu boju")
("use a yellow color" "koristi ºutu boju")
("use as master" "koristi kao master")
("use blackboard bold font" "koristi dvostruka podebljana slova")
("use bold font series" "koristi podebljana slova")
("use calligraphical font" "koristi kaligrafska slova")
("use CSS for more advanced formatting" "koristi CSS za naprednije oblikovanje")
("use extensible brackets" "koristi pro²iruju¢e zagrade")
("use footnote font size" "koristi veli£inu fonta za fusnote")
("use fraktur font" "koristi fraktur font")
("use high resolution fonts" "koristi fontove visoke razlu£ivosti")
("use high resolution icons" "koristi ikone visoke razlu£ivosti")
("use huge font size" "koristi golemu veli£inu slova")
("use Inkscape for conversion from SVG" "upotrijebi Inkscape za pretvorbu iz SVG formata")
("use italic font shape" "koristi kurziv")
("use large font size" "koristi veliku veli£inu slova")
("use left hand column as border" "koristi stupac slijeva kao rub")
("use line wrapping for lines which are longer than 80 characters" "koristi omatanje za retke u kojima broj znakova prelazi 80")
("use medium font series" "koristi slova srednje veli£ine")
("use normal font size" "koristi slova normalne veli£ine")
("use package" "koristi paket")
("use paragraph width" "koristi ²irinu odlomka")
("use print dialogue" "koristi dijalog za ispis")
("use protrusion" "koristi izbo£enje")
("use really huge font size" "koristi zaista golemu veli£inu slova")
("use relative path" "koristi relativnu stazu")
("use right font shape" "koristi pravi oblik slova")
("use right hand column as border" "koristi desni stupac kao rub")
("use roman font family" "koristi latini£ne fontove")
("use row above as border" "koristi gornji redak kao rub")
("use row below as border" "koristi donji redak kao rub")
("use sans serif font family" "koristi fontove bez serifa")
("use script font size" "koristi skript veli£inu slova")
("use slanted font shape" "koristi nako²ena slova")
("use small capitals" "koristi mali verzal")
("use small font size" "koristi malenu veli£inu slova")
("use small-caps font shape" "koristi smanjena velika slova")
("use the blackboard bold font" "koristi dvostruka podebljana slova")
("use the fraktur font" "koristi fraktur font")
("use tiny font font size" "koristi sitnu veli£inu fonta")
("use typewriter font family" "koristi font pisa¢eg stroja")
("use very large font size" "koristi vrlo veliku veli£inu slova")
("user interface" "korisni£ko su£elje")
("user interface language" "jezik korisni£kog su£elja")
("user manual" "priru£nik za korisnike")
("user preferences" "korisni£ke postavke")
("user provided icons" "korisni£ke ikone")
("users of Cyrillic languages" "za korisnike ¢irili£nih jezika")
("users of oriental languages" "za korisnike orijentalnih jezika")
("uTF-8 with inputenc LaTeX package" "UTF-8 s LaTeX paketom fontenc")
("utilities" "korisni programi")
("value" "vrijednost")
("vanish" "i²£ezni")
("variable" "varijabla")
("variance" "varijanca")
("variant" "varijanta")
("vector" "vektor")
("velocity" "brzina")
("verbatim" "doslovno")
("verbose" "op²irno")
("verse" "stih")
("version" "ina£ica")
("versioning tool" "alat za ina£ice")
("vertical" "vertikalno")
("vertical after" "vertikalno nakon")
("vertical alignment" "vertikalno poravnavanje")
("vertical before" "vertikalno prije")
("vertical cell alignment" "vertikalno poravnavanje ¢elija")
("vertical cell padding" "vertikalna ispuna ¢elije")
("vertical margins" "vertikalne margine")
("vertical padding" "vertikalno ispunjavanje")
("vertical part" "vertikalni dio")
("vertical position" "vertikalni poloºaj")
("vertical space" "vertikalni razmak")
("vertical space after" "vertikalni razmak iza")
("vertical space before" "vertikalni razmak ispred")
("vertical space stretchability" "elasti£nost okomitog razmaka")
("vertical table alignment" "vertikalno poravnavanje tablice")
("vertically align cell to the base" "vertikalno poravnavanje ¢elije s obzirom na osnovicu")
("vertically center the cell" "vertikalno centriranje ¢elije")
("very large" "vrlo veliko")
("very small" "vrlo maleno")
("vietnamese" "vijetnamski")
("view" "prikaºi")
("viscosity" "viskoznost")
("visible" "vidljivo")
("visited color" "boja nakon posje¢ivanja")
("visible except here" "vidljivo osim ovdje")
("visible from here on" "vidljivo odavde")
("visible only here" "vidljivo samo ovdje")
("visible until here" "vidljivo do ovdje")
("visited loci" "posje¢eni lokusi")
("volume" "volumen")
("wallet" "lisnica")
("warning" "upozorenje")
("wave" "val")
("wave length" "valna duljina")
("web" "web")
("weight" "teºina")
("welcome" "dobrodo²li")
("welcome to GNU TeXmacs" "dobrodo²li u GNU TeXmacs")
("what is new" "²to je novo")
("when finished" "po zavr²etku")
("when line wrapping" "pri omatanju redaka")
("when wrapping" "pri omatanju")
("while" "while")
("white" "bijelo")
("whitespace" "razmak")
("wide" "²iroko")
("wide accent" "²iroki naglasak")
("wide bar" "²iroka crta")
("wide block" "²iroki blok")
("wide colored" "²iroko obojeno")
("wide float" "²iroko plutaju¢e")
("wide footnote" "²iroka fusnota")
("wide tabbed" "²iroko tabelirano")
("wide tabular" "²iroko tabeliranje")
("widescreen" "²irokozaslonski")
("width" "²irina")
("width is exactly the specified width" "²irina je to£no jednaka specificiranoj")
("width is maximum of specified width and box width" "²irina je maksimum specificirane ²irine i ²irine kutije")
("width is minimum of specified width and box width" "²irina je minimum specificirane ²irine i ²irine kutije")
("width magnification" "pove¢anje ²irine")
("window" "prozor")
("window height" "visina prozora")
("window width" "²irina prozora")
("windows" "prozori")
("windows key" "tipka s Windows logom")
("with" "sa")
("with newer version" "s novijom ina£icom")
("with older version" "sa starijom ina£icom")
("with TeXmacs text" "s tekstom TeXmacsa")
("with title font" "s fontom naslova")
("wood" "drvo")
("word count" "broj rije£i")
("work" "rad")
("wrap lines" "omatanje redaka")
("write a macro" "upi²i makro")
("write a name" "upi²i naziv")
("write bold mathematics" "podebljani matemati£ki znakovi")
("write bold text" "podebljan tekst")
("write italic text" "tekst u kurzivu")
("write sample text" "tekst bez serifa")
("write strong text" "podebljan tekst")
("write typewriter text" "tekst pisa¢eg stroja")
("write verbatim text" "doslovan tekst")
("writing data converters" "pisanje pretvara£a podataka")
("writing documentation" "pisanje dokumentacije")
("writing TeXmacs bibliography styles" "stvaranje stilova popisa literature za TeXmacs")
("writing your own style files" "stvaranje vlastitih stilova")
("written with TeXmacs" "napisano u TeXmacsu")
("wrong empty passphrase" "pogre²na prazna zaporka")
("wrong passphrase" "pogre²na zaporka")
("w.r.t." "s obzirom na")
("xml" "XML")
("xperiment" "eksperiment")
("year" "godina")
("yellow" "ºuto")
("yes" "da")
("you can also obtain" "takoer je mogu¢e dobiti")
("you are attempting to open an encrypted file while" "poku²aj otvaranja ²ifriranu datoteku dok")
("you might consider enabling the experimental" "mogli biste razmotriti omogu¢avanje eksperimentalnog")
("you must add a bibliography file" "morate dodati datoteku s popisom literature")
("you should also make sure that GnuPG is installed" "takoer biste trebali biti sigurni da je GnuPG instaliran")
("your personal dictionary has been modified" "osobni rje£nik je promijenjen")
("your document is back in its original state" "dokument je vra¢en u prvobitno stanje")
("your first interface" "va²e prvo su£elje")
("your language" "va² jezik")
("zigzag" "cik-cak")
("zoom" "pove¢anje")
("zoom factor" "faktor pove¢anja")
("zoom in" "pove¢aj")
("zoom out" "umanji")
